/* WooCommerce styles
----------------------------------------------------------------- */

@import "../../../../css/_mixins.scss";
@import "../../../../css/_theme-vars.scss";
@import "../../css/_skin-vars.scss";


/* Common styles
----------------------------------------------------------------- */
body.woocommerce {
	--theme-var-sidebar_width_min: 250px;		// Sidebar min width on WooCommerce pages
	@include page_dimensions;
}
.woocommerce table th, .woocommerce table td {
	border-width:0;
}

/* Buttons */
body.woocommerce-page form.lost_reset_password .woocommerce-form-row button.button,
.woocommerce #btn-buy,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button,
.woocommerce #respond input#submit,
.woocommerce .button, .woocommerce-page .button,
.woocommerce a.button,
.woocommerce button.button,
.woocommerce input.button,
.woocommerce input[type="button"], .woocommerce-page input[type="button"],
.woocommerce input[type="submit"], .woocommerce-page input[type="submit"],
.woocommerce ul.products li.product .button,
.woocommerce div.product form.cart .button,
.woocommerce #review_form #respond p.form-submit input[type="submit"],
.woocommerce-page #review_form #respond p.form-submit input[type="submit"],
.woocommerce table.my_account_orders .order-actions .button,
.woocommerce table.cart td.actions .button,
#add_payment_method .wc-proceed-to-checkout a.checkout-button,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button,
.yith-woocompare-widget a.clear-all {
	@include theme_button_filled;
	@include box-shadow(none);
}
body.woocommerce-page form.lost_reset_password .woocommerce-form-row button.button:hover,
.woocommerce #btn-buy:hover,
.woocommerce #btn-buy:focus,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button:hover,
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button:focus,
.woocommerce #respond input#submit:hover,
.woocommerce #respond input#submit:focus,
.woocommerce .button:hover, .woocommerce-page .button:hover,
.woocommerce .button:focus, .woocommerce-page .button:focus,
.woocommerce a.button:hover, .woocommerce-page a.button:hover,
.woocommerce a.button:focus, .woocommerce-page a.button:focus,
.woocommerce button.button:hover, .woocommerce-page button.button:hover,
.woocommerce button.button:focus, .woocommerce-page button.button:focus,
.woocommerce input.button:hover, .woocommerce-page input.button:hover,
.woocommerce input.button:focus, .woocommerce-page input.button:focus,
.woocommerce input[type="button"]:hover, .woocommerce-page input[type="button"]:hover,
.woocommerce input[type="button"]:focus, .woocommerce-page input[type="button"]:focus,
.woocommerce input[type="submit"]:hover, .woocommerce-page input[type="submit"]:hover,
.woocommerce input[type="submit"]:focus, .woocommerce-page input[type="submit"]:focus,
.woocommerce ul.products li.product .button:hover,
.woocommerce ul.products li.product .button:focus,
.woocommerce div.product form.cart .button:hover,
.woocommerce div.product form.cart .button:focus,
.woocommerce #review_form #respond p.form-submit input[type="submit"]:hover,
.woocommerce #review_form #respond p.form-submit input[type="submit"]:focus,
.woocommerce-page #review_form #respond p.form-submit input[type="submit"]:hover,
.woocommerce-page #review_form #respond p.form-submit input[type="submit"]:focus,
.woocommerce table.my_account_orders .order-actions .button:hover,
.woocommerce table.my_account_orders .order-actions .button:focus,
.woocommerce table.cart td.actions .button:hover,
.woocommerce table.cart td.actions .button:focus,
#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover,
#add_payment_method .wc-proceed-to-checkout a.checkout-button:focus,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:focus,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:focus,
.yith-woocompare-widget a.clear-all:hover,
.yith-woocompare-widget a.clear-all:focus {
	@include theme_button_colors_hover;
}

/* Disabled state */
.woocommerce #respond input#submit.disabled,
.woocommerce #respond input#submit:disabled,
.woocommerce #respond input#submit[disabled]:disabled,
.woocommerce a.button.disabled,
.woocommerce a.button:disabled,
.woocommerce a.button[disabled]:disabled,
.woocommerce button.button.disabled,
.woocommerce button.button:disabled,
.woocommerce button.button[disabled]:disabled,
.woocommerce input.button.disabled,
.woocommerce input.button:disabled,
.woocommerce input.button[disabled]:disabled {
	@include theme_button_filled;
}
.woocommerce #respond input#submit.disabled,
.woocommerce #respond input#submit:disabled,
.woocommerce #respond input#submit[disabled]:disabled,
.woocommerce a.button.disabled,
.woocommerce a.button:disabled,
.woocommerce a.button[disabled]:disabled,
.woocommerce button.button.disabled,
.woocommerce button.button:disabled,
.woocommerce button.button[disabled]:disabled,
.woocommerce input.button.disabled,
.woocommerce input.button:disabled,
.woocommerce input.button[disabled]:disabled,
.woocommerce #respond input#submit.disabled:hover,
.woocommerce #respond input#submit:disabled:hover,
.woocommerce #respond input#submit[disabled]:disabled:hover,
.woocommerce a.button.disabled:hover,
.woocommerce a.button:disabled:hover,
.woocommerce a.button[disabled]:disabled:hover,
.woocommerce button.button.disabled:hover,
.woocommerce button.button:disabled:hover,
.woocommerce button.button[disabled]:disabled:hover,
.woocommerce input.button.disabled:hover,
.woocommerce input.button:disabled:hover,
.woocommerce input.button[disabled]:disabled:hover {
	@include theme_button_disabled(!important);
}

/* Alt buttons */
.woocommerce #respond input#submit.alt,
.woocommerce a.button.alt,
.woocommerce button.button.alt,
.woocommerce input.button.alt {
	@include theme_button_colors;
}
.woocommerce #respond input#submit.alt:hover,
.woocommerce #respond input#submit.alt:focus,
.woocommerce a.button.alt:hover,
.woocommerce a.button.alt:focus,
.woocommerce button.button.alt:hover,
.woocommerce button.button.alt:focus,
.woocommerce input.button.alt:hover,
.woocommerce input.button.alt:focus {
	@include theme_button_colors_hover;
}

/* Buttons in widgets */
.widget.woocommerce .button,
.widget.WOOCS_CONVERTER .button,
.widget.yith-woocompare-widget a.button,
.widget.yith-woocompare-widget a.clear-all,
.woocommerce .widget_price_filter .price_slider_amount .button {
	@include font(15px, 18px);
	padding: 15px 35px;
}
.widget.woocommerce .button+.button {
	margin-left: 3px;
}

[class*="scheme_"].sidebar .woocommerce-message .button,
[class*="scheme_"].sidebar .woocommerce-error .button,
[class*="scheme_"].sidebar .woocommerce-info .button,
[class*="scheme_"].sidebar .widget.woocommerce .button,
[class*="scheme_"].sidebar .widget.woocommerce a.button,
[class*="scheme_"].sidebar .widget.woocommerce button.button,
[class*="scheme_"].sidebar .widget.woocommerce input.button,
[class*="scheme_"].sidebar .widget.woocommerce input[type="button"],
[class*="scheme_"].sidebar .widget.woocommerce input[type="submit"],
[class*="scheme_"].sidebar .widget.WOOCS_CONVERTER .button,
[class*="scheme_"].sidebar .widget.yith-woocompare-widget a.button,
[class*="scheme_"].sidebar .widget_product_search .search_button {
	@include theme_button_colors_style_alter();
}
[class*="scheme_"].sidebar .woocommerce-message .button:hover,
[class*="scheme_"].sidebar .woocommerce-message .button:focus,
[class*="scheme_"].sidebar .woocommerce-error .button:hover,
[class*="scheme_"].sidebar .woocommerce-error .button:focus,
[class*="scheme_"].sidebar .woocommerce-info .button:hover,
[class*="scheme_"].sidebar .woocommerce-info .button:focus,
[class*="scheme_"].sidebar .widget.woocommerce .button:hover,
[class*="scheme_"].sidebar .widget.woocommerce .button:focus,
[class*="scheme_"].sidebar .widget.woocommerce a.button:hover,
[class*="scheme_"].sidebar .widget.woocommerce a.button:focus,
[class*="scheme_"].sidebar .widget.woocommerce button.button:hover,
[class*="scheme_"].sidebar .widget.woocommerce button.button:focus,
[class*="scheme_"].sidebar .widget.woocommerce input.button:hover,
[class*="scheme_"].sidebar .widget.woocommerce input.button:focus,
[class*="scheme_"].sidebar .widget.woocommerce input[type="button"]:hover,
[class*="scheme_"].sidebar .widget.woocommerce input[type="button"]:focus,
[class*="scheme_"].sidebar .widget.woocommerce input[type="submit"]:hover,
[class*="scheme_"].sidebar .widget.woocommerce input[type="submit"]:focus,
[class*="scheme_"].sidebar .widget.WOOCS_CONVERTER .button:hover,
[class*="scheme_"].sidebar .widget.WOOCS_CONVERTER .button:focus,
[class*="scheme_"].sidebar .widget.yith-woocompare-widget a.button:hover,
[class*="scheme_"].sidebar .widget.yith-woocompare-widget a.button:focus,
[class*="scheme_"].sidebar .widget_product_search .search_button:hover,
[class*="scheme_"].sidebar .widget_product_search .search_button:focus {
	@include theme_button_colors_hover_style_alter();
}

.single-product div.product .woocommerce-tabs .wc-tabs li a,
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container-single .chosen-single {
	@include border-radius(0);
}

.woocommerce ul.products li.product .post_featured.hover_shop_buttons .icons a {
	@include border-sharp;
}

.woocommerce div.product form.cart div.quantity span,
.woocommerce-page div.product form.cart div.quantity span,
.woocommerce .shop_table.cart div.quantity span,
.woocommerce-page .shop_table.cart div.quantity span {
	color: var(--theme-color-input_text);
	@include transition-color(0.3s);
	&:hover {
		color: var(--theme-color-input_dark);
	}
}
.woocommerce div.product form.cart div.quantity input[type="number"], .woocommerce-page div.product form.cart div.quantity input[type="number"],
.woocommerce .shop_table.cart input[type="number"], .woocommerce-page .shop_table.cart div.quantity input[type="number"] {
	border-color: var(--theme-color-text_link);
}
.woocommerce div.product form.cart div.quantity span.q_inc,
.woocommerce-page div.product form.cart div.quantity span.q_inc,
.woocommerce .shop_table.cart div.quantity span.q_inc,
.woocommerce-page .shop_table.cart div.quantity span.q_inc {
	@include border-radius( 0 30px 0 0 );
}
.woocommerce div.product form.cart div.quantity span.q_dec,
.woocommerce-page div.product form.cart div.quantity span.q_dec,
.woocommerce .shop_table.cart div.quantity span.q_dec,
.woocommerce-page .shop_table.cart div.quantity span.q_dec {
	@include border-radius( 0 0 30px 0 );
}


/* Text fields */
.woocommerce table.cart td.actions .coupon .input-text,
.woocommerce #content table.cart td.actions .coupon .input-text,
.woocommerce-page table.cart td.actions .coupon .input-text,
.woocommerce-page #content table.cart td.actions .coupon .input-text {
	@include theme_field_template;
}


/* Shop Listing
----------------------------------------------------------------- */

.woocommerce ul.products:before,.woocommerce-page ul.products:before,
.woocommerce .products ul:before, .woocommerce-page .products ul:before,
.woocommerce div.product #reviews .comment:before, .woocommerce-page div.product #reviews .comment:before,
.woocommerce #content div.product #reviews .comment:before, .woocommerce-page #content div.product #reviews .comment:before,
.woocommerce .woocommerce-pagination ul.page-numbers:before, .woocommerce-page .woocommerce-pagination ul.page-numbers:before {
	display:none;
}

.woocommerce .list_products_header, .woocommerce-page .list_products_header {
	padding: 0;
	margin-bottom:2em;
	display: none;
}
.woocommerce .woocommerce-breadcrumb {
	@include font(15px, 19px);
	color: var(--theme-color-text);
	.woocommerce-breadcrumb-delimiter {
		margin: 0 0.3em;
		&:before {
			content: '/';
		}
	}
	a {
	color: var(--theme-color-text);
		&:hover {
			color: var(--theme-color-text_dark);
		}
	}
}
.woocommerce .post_item_single .woocommerce-breadcrumb {
	margin: -2em 0 3em;
	display: none;
}
.woocommerce.sidebar_show .post_item_single .woocommerce-breadcrumb {
	margin-top: 0;
}
.woocommerce .post_item_single .summary > .woocommerce-breadcrumb {
	margin-top: -2px;
	margin-bottom: 2em;
}
.woocommerce .page-title {
	margin:0;
}

.woocommerce ul.products li.product .button,
.woocommerce div.product form.cart .button {
	margin-top: 0;
}

.woocommerce ul.products li.product .add_to_cart:before,
.woocommerce div.product form.cart .button:before {
	content: '\e93d';
	font-family:$theme_icons;
	margin-right:0.6em;
	display: none;
}

.woocommerce ul.products li.product.outofstock a[class*="add_to_cart"] {
    display: none;
}
.woocommerce ul.products li.product .outofstock_label {
	@include abs-lt(20px, 20px, 10);
	background-color: #222733;
	color: #fff;
	text-align: center;
	display: block;
	font-size: 11px;
	font-weight: 700;
	height: 25px;
	line-height: 25px;
	min-height: 25px;
	min-width: 66px;
	width: auto;
	letter-spacing: 0.8px;
	margin: 0;
	padding: 0 18px;
	text-transform: uppercase;
	@include border-radius(0);
	+ .onsale {
		left: auto;
		right: 20px;
	}
}

.woocommerce .woocommerce-result-count {
	margin: 0 0.3em 0 0;
	font-size: 15px;
	line-height: 22px;
	color: var(--theme-color-text_light);
}

.woocommerce .woocommerce-ordering {
	margin: 0 0 2.8em;
	width: 245px;
	.select_container {
		line-height: 1;
		&:before {
			content: '';
			display: block;
			position: absolute;
			z-index: 1;
			top: 2px;
			right: 2px;
			bottom: 2px;
			left: auto;
			width: 25px;
		}
		&:after {
			content: '\e9e6';
			font-family: $theme_icons;
			font-size: 10px;
			display: block;
			position: absolute;
			z-index: 2;
			top: 50%;
			right: 0;
			width: 1em;
			height: 1em;
			line-height: 1em;
			text-align: center;
			margin-top: -0.5em;
			color: var(--theme-color-text_dark);
			@include transform(rotate(90deg));
		}
	}
	select {
		border: none !important;
		background: none !important;
		font-size: 15px;
		line-height: 22px;
		font-weight: inherit;
		color: var(--theme-color-text_dark);
		padding: 0 25px 0 0 !important;
	}
}


.sidebar_show.woocommerce ul.products.columns-4, .sidebar_show.woocommerce-page ul.products.columns-4,
.woocommerce ul.products.columns-5, .woocommerce-page ul.products.columns-5,
.woocommerce ul.products.columns-6, .woocommerce-page ul.products.columns-6,
.woocommerce ul.products.columns-7, .woocommerce-page ul.products.columns-7,
.woocommerce ul.products.columns-8, .woocommerce-page ul.products.columns-8 {
	font-size: 0.9286em;
}
.sidebar_show.woocommerce ul.products.columns-4 a.button, .sidebar_show.woocommerce-page ul.products.columns-4 a.button,
.woocommerce ul.products.columns-5 a.button, .woocommerce-page ul.products.columns-5 a.button,
.woocommerce ul.products.columns-6 a.button, .woocommerce-page ul.products.columns-6 a.button {
	padding: 1em 1.5em;
}

.woocommerce ul.products,
.woocommerce-page ul.products {
	margin-right: -30px;
	margin-bottom:0;
	@include flex;
	@include flex-wrap(wrap);
}
.woocommerce ul.products li.product > .post_item.post_layout_thumbs {
	@include flex;
	@include flex-direction(column);
	@include border-box;
	@include box(100%, 100%);
}
.woocommerce .products.related ul.products li.product > .post_item.post_layout_thumbs {
	height: auto;
}
.woocommerce ul.products li.product,
.woocommerce ul.products[class*="columns-"] li.product,
.woocommerce[class*="columns-"] ul.products li.product,
.woocommerce-page ul.products li.product,
.woocommerce-page[class*="columns-"] ul.products li.product,
.woocommerce-page ul.products[class*="columns-"] li.product {
    margin: 0;
	clear:none;
    padding: 0 30px 35px 0;
    position: relative;
	width: 50%;
	@include border-box;
}
@for $i from 1 through 8 {
	.woocommerce.columns-#{$i} ul.products li.product,
	.woocommerce ul.products.columns-#{$i} li.product,
	.woocommerce ul.products li.product.column-1_#{$i},
	.woocommerce .related.products ul.products.columns-#{$i} li.product,
	.woocommerce .related.products ul.products li.product.column-1_#{$i},
	.woocommerce .upcells.products ul.products li.product.column-1_#{$i},
	.woocommerce .upcells.products ul.products.columns-#{$i} li.product,
	.woocommerce-page.columns-#{$i} ul.products li.product,
	.woocommerce-page ul.products.columns-#{$i} li.product,
	.woocommerce-page ul.products li.product.column-1_#{$i},
	.woocommerce-page .related.products ul.products.columns-#{$i} li.product,
	.woocommerce-page .related.products ul.products li.product.column-1_#{$i},
	.woocommerce-page .upcells.products ul.products.columns-#{$i} li.product,
	.woocommerce-page .upcells.products ul.products li.product.column-1_#{$i} {
		width: 100% / $i;
	}
}

// For Elementor Pro
.elementor-products-grid .woocommerce ul.products.elementor-grid {
	margin: 0;
	li.product {
		width: 100% !important;
		padding: 0;
	}
}

.woocommerce ul.products li.product-category mark,
.woocommerce-page ul.products li.product-category mark {
	background:none;
}

.woocommerce ul.products li.product .post_item,
.woocommerce-page ul.products li.product .post_item {
	margin-bottom:0;
	@include transition-colors;
}
.woocommerce ul.products li.product .post_featured {
	@include flex-shrink(0);
	overflow: hidden;
	margin-bottom: 27px;
	border: none;
}

/* Thumbs mode */
.woocommerce .shop_mode_thumbs ul.products li.product .post_item,
.woocommerce-page .shop_mode_thumbs ul.products li.product .post_item {
	outline: none;
}
.woocommerce .shop_mode_thumbs ul.products li.product .post_item:hover,
.woocommerce-page .shop_mode_thumbs ul.products li.product .post_item:hover {
	outline: none;
}
.woocommerce ul.products li.product a img, .woocommerce-page ul.products li.product a img,
.woocommerce ul.products li.product a:hover img, .woocommerce-page ul.products li.product a:hover img {
	margin: 0;
	@include box-shadow(none);
}
.woocommerce ul.products li.product a img, .woocommerce-page ul.products li.product a img {
	@include transition-properties(opacity, transform);
}
.woocommerce ul.products li.product .post_featured:hover img,
.woocommerce-page ul.products li.product .post_featured:hover img,
.woocommerce ul.products li.product a:hover img,
.woocommerce-page ul.products li.product a:hover img {
	@include scale(1.1, 1.1);
}
.woocommerce ul.products li.product .onsale,
.woocommerce-page ul.products li.product .onsale {
	font-size: 11px;
	font-weight: 700;
	@include box(auto, 25px, 25px);
	min-height: 25px;
	min-width: 50px;
	max-width: 55%;
	letter-spacing: 0.8px;
	margin: 0;
	padding: 0 12px;
	left: 20px;
	text-transform: uppercase;
	top: 20px;
	right: auto;
	@include border-radius(0);
	background: var(--theme-color-text_link);
	position: absolute;
	overflow: hidden;
}

.woocommerce ul.products li.product strong {
	margin-top: 0.5em;
}
.woocommerce ul.products li.product .post_data,
.woocommerce-page ul.products li.product .post_data {
	padding: 0;
	text-align: left;
	overflow: hidden;
	.post_data_inner > div + .button.product_type_variable,
	.post_data_inner > div + .button.product_type_simple,
	.add_to_cart_wrap {
		margin-top: 18px;
	}
	.post_data_inner {
		.button {
			padding: 14px 44px;
			@include box-shadow(none);
			&:after {
				animation: none;
			}
		}
		.added_to_cart {
			display: block;
			padding: 0;
			margin-top: 0.5em;
		}
	}
}

.woocommerce ul.products li.product.outofstock .post_featured:not(.hover_none)+.post_data .button,
.woocommerce-page ul.products li.product.outofstock .post_featured:not(.hover_none)+.post_data .button,
.woocommerce ul.products li.product .post_featured:not(.hover_none)+.post_data .add_to_cart_button,
.woocommerce-page ul.products li.product .post_featured:not(.hover_none)+.post_data .add_to_cart_button,
.woocommerce ul.products li.product .post_featured:not(.hover_none)+.post_data .button.product_type_external,
.woocommerce-page ul.products li.product .post_featured:not(.hover_none)+.post_data .button.product_type_external,
.woocommerce ul.products li.product .post_featured:not(.hover_none)+.post_data .button.product_type_grouped,
.woocommerce-page ul.products li.product .post_featured:not(.hover_none)+.post_data .button.product_type_grouped {
	display:none;
}

.woocommerce ul.products li.product .post_header a {
	color: var(--theme-color-alter_dark);
}
.woocommerce ul.products li.product .post_header a:hover {
	color: var(--theme-color-alter_link);
}
.woocommerce ul.products li.product .post_header .post_tags {
	@include font(14px, 1.4em, 400, normal);
	letter-spacing: 0;
	margin-bottom: 0.5em;
}
.woocommerce ul.products li.product .post_header .post_tags,
.woocommerce ul.products li.product .post_header .post_tags a {
	color: var(--theme-color-alter_text);
}
.woocommerce ul.products li.product .post_header .post_tags a:hover {
	color: var(--theme-color-text_hover);
}
.woocommerce ul.products li.product .post_header, .woocommerce-page ul.products li.product .post_header {
	margin-bottom:0;
}
.woocommerce ul.products li.product .woocommerce-loop-category__title,
.woocommerce ul.products li.product .woocommerce-loop-product__title,
.woocommerce ul.products li.product h3 {
	@include font(19px, 1.3em, 700);
	letter-spacing: 0;
	margin-top:0;
	margin-bottom: 0;
	padding:0;
}
.search-results .product .price,
.woocommerce ul.products li.product .price,
.woocommerce-page ul.products li.product .price {
	@include font(18px, 1em, 700);
	margin: 11px 0 0 0;
}
.search-results .product .price {
	margin: 0 0 11px 0;
}
.woocommerce ul.products.columns-6 li.product .post_featured .icons {
	display: none !important;
}

span.amount {
	line-height:1em;
}
span.amount > .decimals {
	position:relative;
	display:inline;
	@include font(0.75em, 1em);
	vertical-align:top;
	margin-left:0.2em;
}
span.amount > .decimals_separator {
	display:none;
}
.woocommerce div.product p.price,
.woocommerce div.product span.price,
.woocommerce span.amount,
.woocommerce-page span.amount {
	color: var(--theme-color-alter_text);
}
.woocommerce table.shop_table tr.cart-discount td,
.woocommerce table.shop_table td span.amount {
	color: var(--theme-color-alter_text);
}

.woocommerce ul.products li.product .price .decimals,
.woocommerce-page ul.products li.product .price .decimals {
	top: -0.2em;
}
.search-results .product .price ins,
.woocommerce ul.products li.product .price ins {
	text-decoration:none;
	font-weight:inherit;
	font-style:inherit;
}
.search-results .product .price del,
.woocommerce ul.products li.product .price del {
	display:inline-block;
	margin-right: 6px;
	font-size: 1em;
	opacity:1;
	text-decoration:none;
	position:relative;
}
.search-results .product .price del:before,
.woocommerce ul.products li.product .price del:before {
	content:' ';
	@include abs-lt(0, 55%);
	@include box(100%, 1px);
}
.woocommerce ul.products li.product .price,
.woocommerce-page ul.products li.product .price,
.search-results .product .price ins,
.woocommerce ul.products li.product .price ins,
.woocommerce-page ul.products li.product .price ins {
	color: var(--theme-color-alter_text);
}
.search-results .product .price del,
.woocommerce ul.products li.product .price del,
.woocommerce-page ul.products li.product .price del {
	color: var(--theme-color-alter_text);
}
.search-results .product .price del:before,
.woocommerce .price del:before {
	background-color: var(--theme-color-text_light);
}
.search-results .product .price del > span.amount,
aside.woocommerce del,
.woocommerce del, .woocommerce del > span.amount,
.woocommerce del, .woocommerce del > span.amount *,
.woocommerce-page del, .woocommerce-page del > span.amount,
.woocommerce-page del, .woocommerce-page del > span.amount * {
	color: var(--theme-color-text_light) !important;
}


/* Thumbs mode */
.woocommerce .shop_mode_thumbs ul.products li.product .price,
.woocommerce-page .shop_mode_thumbs ul.products li.product .price {
	margin: 11px 0 0;
}

.woocommerce a.added_to_cart,
.woocommerce-page a.added_to_cart {
	padding: 1.3em 0 0 1em;
    vertical-align: top;
	line-height:1em;
}
.woocommerce #respond input#submit.loading:after, .woocommerce a.button.loading:after, .woocommerce button.button.loading:after, .woocommerce input.button.loading:after {
	display: none;
}


/* Rating stars */
.woocommerce .products .star-rating {
	float:none;
	margin: 0.6em auto -0.6em;
}
.woocommerce ul.products li.product .post_header {
	position:relative;
	overflow: visible;
}
.woocommerce ul.products li.product .star-rating {
	font-size: 14px;
	width: 78px;
	margin: 15px 0 0;
	letter-spacing: 2px;
}
.woocommerce .products .star-rating:before,
.woocommerce .products .star-rating span {
	top: 0;
	left: 1px;
}
.woocommerce .star-rating span:before,
.woocommerce .star-rating:before {
	content: "\e96e\e96e\e96e\e96e\e96e";
	font-family: $theme_icons;
}
.woocommerce p.stars a,
.star-rating span,
.star-rating:before {
	color: #FFC107;
}
.woocommerce .star-rating:before {
	color: var(--theme-color-text_dark_02);
}
.woocommerce p.stars a:hover {
	color: var(--theme-color-text_link);
}
#review_form #respond p.form-submit input[type="submit"] {
	color: var(--theme-color-inverse_link);
	background-color: var(--theme-color-text_link);
}
#review_form #respond p.form-submit input[type="submit"]:hover,
#review_form #respond p.form-submit input[type="submit"]:focus {
	color: var(--theme-color-bg_color);
	background-color: var(--theme-color-text_dark);
}

/* Pagination */
.woocommerce-links-more + .woocommerce-pagination {
	display: none;
}


.return-to-shop {
	text-align: center;
}

/* Single product decoration
---------------------------------------------------------------------------- */

/* Messages */
.woocommerce .woocommerce-message,
.woocommerce .woocommerce-info {
	background-color: transparent;
	border: none;
	margin: 0 0 48px 0;
}
.woocommerce form.checkout_coupon,
.woocommerce form.login,
.woocommerce form.register {
	border: none;
	padding: 0;
	margin: 48px auto 0 auto;
	text-align: center;
}
.woocommerce-error,
.woocommerce-info,
.woocommerce-message {
	padding: 0;
	margin: 0;
	text-align: center;
	font-size: 1em;
	font-weight: 400;
	border: none;
	background-color: transparent;
	color: var(--theme-color-text);
	a {
		font-weight: 500;
		color: var(--theme-color-text_dark);
		&:hover {
			color: var(--theme-color-text_link);
		}
	}
}
.woocommerce .woocommerce-error {
	text-align: center;
	padding: 35px 0 0 0;
	margin: 0 0 50px 0;
	&:before {
		top: 0;
		left: 50%;
		@include transform(translateX(-50%));
	}
}

.woocommerce .woocommerce-message:before,
.woocommerce .woocommerce-info:before {
	color: var(--theme-color-alter_dark);
}
.woocommerce .woocommerce-error:before {
	color: var(--theme-color-alter_link);
}
.woocommerce .woocommerce-error .button,
.woocommerce .woocommerce-info .button,
.woocommerce .woocommerce-message .button {
	margin: 0;
	padding: 0;
	display: inline-block;
	@include border-radius(0);
	@include box-shadow(none !important);
	background-color: transparent !important;
	float: none;
	color: var(--theme-color-text_link);
	letter-spacing: 0;
	font-size: inherit;
	line-height: inherit;
	margin-right: 5px;
	&:focus,
	&:hover {
		color: var(--theme-color-text_hover);
	}
}
.woocommerce .woocommerce-message:before,
.woocommerce .woocommerce-info:before {
	display: none;
}

.woocommerce-checkout .woocommerce-form-coupon-toggle .woocommerce-info {
	margin: 0;
}

// new wc-block
.wc-block-components-notice-banner[class*="wc-block"] {
	@include border-radius(0);
	@include font(0.9em, 1.4em, inherit);
	color: var(--theme-color-text);
	background-color: transparent !important;
	margin: 0 0 calc(var(--theme-var-grid_gap) * 2) 0;
	&.is-error { 
		border-color: #FF5B4A;
		> svg {	background-color: #FF5B4A; }
	}
	&.is-warning {}
	&.is-success {}
	&.is-info {}
	a {
		color: var(--theme-color-text_dark);
		&:hover,
		&:focus {
			color: var(--theme-color-text_link);
		}
	}
	> .wc-block-components-notice-banner__content .wc-forward {
		display: block;
		width: fit-content;
		@include box-shadow(none);
		@include border-radius(0);
		@include font(inherit, inherit, inherit);
		text-transform: inherit;
		letter-spacing: inherit;
		background-color: transparent;
		text-decoration-line: underline;
		opacity: 1;
		color: var(--theme-color-text_dark) !important;
		font-family: inherit;
		margin-left: 5px;
		@media #{$media_sm} {
			margin: 0 0 8px 0;
			float: none;
		}
		&:hover,
		&:focus {
			color: var(--theme-color-text_link) !important;
		}
	}
	.woocommerce-form-coupon-toggle & {
		margin-bottom: 0;
	}
}

/* coupon */
.woocommerce-form-coupon-toggle {
	margin-bottom: 0;
	padding-bottom: 10px;
}

.woocommerce-form-coupon {
	p {
		font-size: 15px;
		line-height: 1.3em;
		font-weight: 400;
		margin: 23px 0 0 0;
	}
	.cart-coupon-inner {
		@include flex;
		position: relative;
		border: 1px solid var(--theme-color-bd_color);
		align-items: center;
		padding-left: 25px;
		height: 55px;
		margin: 0 auto;
		width: 530px;
		@include box-sizing(border-box);
		@include border-radius(0);
		&:before {
			content: '\e9bd';
			font-family: $theme_icons;
			display: inline-block;
			color: var(--theme-color-text_dark);
			font-size: 22px;
			font-weight: 400;
		}
		input {
			padding: 13px 10px;
			font-size: 14px;
			font-weight: 400;
			line-height: normal;
			border: none;
			flex: 1 auto;
			width: 100%;
			margin-right: 155px;
		}
		button {
			display: inline-flex;
			width: 155px;
			padding: 0;
			position: absolute;
			top: 0;
			right: 0;
			bottom: 0;
			background: none;
			align-items: center;
			justify-content: center;
			font-size: 15px;
			color: var(--theme-color-text_dark);
			background-color: var(--theme-color-bg_color) !important;
			@include border-radius(0);
			&:focus,
			&:hover {
				color: var(--theme-color-text_link);
			}
			&:before {
				content: "";
				display: block;
				height: 22px;
				width: 1px;
				@include abs-lc();
				background: var(--theme-color-bd_color);
			}
		}
	}
}



/* Title */
.woocommerce div.product .product_title {
	margin: -0.15em 0 0.55em;
	@include font(var(--theme-font-h3_font-size), var(--theme-font-h3_line-height), var(--theme-font-h3_font-weight));
	letter-spacing: var(--theme-font-h3_letter-spacing);
}

/* Des */
.woocommerce div.product .woocommerce-product-details__short-description {
	margin-bottom: 40px;
	p:last-child {
		margin: 0;
	}
}

/* Price */
.woocommerce div.product p.price,
.woocommerce div.product span.price {
	position:relative;
	font-size: 24px;
	font-weight: 700;
	color: var(--theme-color-text_link);
	span.amount {
		color: var(--theme-color-text_link);
	}
	.woocommerce-Price-currencySymbol {
		letter-spacing: 2px;
	}
}
.woocommerce div.product p.price {
	margin: 0 0 35px;
}

.woocommerce div.product span.price ins,
.woocommerce div.product p.price ins {
	text-decoration: none;
	font-style: normal;
	font-weight: 700;
}



/* Images and thumbnails */
.woocommerce, .woocommerce-page {
	--theme-var-single-product-gallery-width: 56%;
}
.woocommerce-main-image {
	position: relative;
	display: block;
}
.woocommerce div.product div.images,
.woocommerce #content div.product div.images, 
.woocommerce-page div.product div.images, 
.woocommerce-page #content div.product div.images {
	margin-bottom: 6.5em;
}
.woocommerce.sidebar_show div.product div.images, .woocommerce-page.sidebar_show div.product div.images,
.woocommerce.sidebar_show #content div.product div.images, .woocommerce-page.sidebar_show #content div.product div.images {
	width: 100%;
	float: none;
	margin-bottom: 60px;
}
.woocommerce.sidebar_hide div.product div.images, .woocommerce-page.sidebar_hide div.product div.images,
.woocommerce.sidebar_hide #content div.product div.images, .woocommerce-page.sidebar_hide #content div.product div.images {
	width: var(--theme-var-single-product-gallery-width);
	float: left;
}

.woocommerce div.product div.images img {
	border: none;
	@include border-box;
}
.woocommerce div.product div.images .woocommerce-product-gallery__image:first-child {
	@include border-box;
}
.woocommerce div.product div.images .woocommerce-product-gallery__image:nth-child(n+2) {
	@include border-box;
}



/* Built-in images slider */
.woocommerce div.product div.images {
	.flex-viewport {
		border: none;
	}
	.woocommerce-product-gallery__wrapper {
		max-width: none;
		display: block;
	}
	.woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image:first-child {
		margin-bottom: 0;
	}
	.woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image:nth-child(n+2) {
		padding: 0;
	}
	.woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image img {
		border: none;
	}
	.flex-control-thumbs li {
		@include border-box;
	}
	img {
		border-color: var(--theme-color-bd_color);
	}
	a:hover img {
		border-color: var(--theme-color-text_link);
	}
}

.woocommerce div.product div.images .woocommerce-product-gallery__trigger {
	display: block;
	overflow: hidden;
	color: #000000 !important;
	background-color: #ffffff !important;
	letter-spacing:0 !important;
	cursor:pointer;
	text-align:center;
	border: none !important;
	margin: 0 !important;
	@include box(47px, 47px, 48px !important);
	@include border-radius(50% !important);
	@include transition(all 0.2s ease !important);
	@include box-shadow(0 0 30px 0 rgba(0, 0, 0, 0.06));
	position: absolute;
	visibility: visible !important;
	pointer-events: auto !important;
	top: 20px;
	right: 20px;
	opacity: 1 !important;
	&:after {
		display: none !important;
	}
	&:before {
		content: '\e9a6';
		font-family: $theme_icons;
		border: none;
		@include border-radius(0);
		position: static;
		font-size: 18px;
		width: 100%;
		height: 100%;
		text-indent: 0;
	}
	&:hover {
		color: var(--theme-color-text_link) !important;
	}
}


.woocommerce div.product div.images {
	position: relative;
	overflow: hidden;
	padding-left: 150px;
	@include box-sizing(border-box);

	&.woocommerce-product-gallery--without-thumbs {
		padding-left: 0 !important;
	}

	.flex-control-thumbs {
		@include abs-lt;
		margin: 0;
		width: 150px;
		padding: 0 50px 0 0;
		@include box-sizing(border-box);
		height: 100%;
		overflow-x: hidden;
		overflow-y: auto;

		/* Scrollbar decoration */
		// Firefox
		scrollbar-width: thin;

		// WebKit-based browsers
		&::-webkit-scrollbar {
			width: 8px;
		}
		&::-webkit-scrollbar-track {
			background: var(--theme-color-alter_bg_color);
		}
		&::-webkit-scrollbar-thumb {
			background-color: var(--theme-color-alter_bd_color);
		}
	}
	.flex-control-thumbs li {
		padding: 0 0 20px 0;
		display: block;
		width: 100%;
		&:last-child {
			padding-bottom: 0 !important;
		}
	}
}

.woocommerce div.product .summary span.onsale {
	font-size: 11px;
	line-height: 15px;
	font-weight: 700;
	margin: 0 0 30px;
	padding: 5px 15px;
	display: table;
	text-transform:uppercase;
	pointer-events: none;
	color: var(--theme-color-inverse_link);
	background-color: var(--theme-color-text_link);
	width: auto;
	min-width: 50px;
	max-width: 200px;
	height: auto;
	min-height: auto;
	@include border-radius(0);
	@include box-sizing(border-box);
	letter-spacing: 0.8px;
	position: static;
}
body:not(.trx_addons_present) div.product span.onsale {
	line-height: 16px;
}
.woocommerce div.product div.thumbnails > div,
.woocommerce div.product div.thumbnails > ul {
	max-height: 15em;
}

.woocommerce #content div.product div.thumbnails a, .woocommerce div.product div.thumbnails a,
.woocommerce-page #content div.product div.thumbnails a, .woocommerce-page div.product div.thumbnails a {
	margin-right: 1.5%;
	width: 18.5%;
	position:relative;
	@include border-box;
}
.woocommerce #content div.product div.thumbnails a:hover, .woocommerce div.product div.thumbnails a:hover,
.woocommerce-page #content div.product div.thumbnails a:hover, .woocommerce-page div.product div.thumbnails a:hover {
	border-style: solid;
}
.woocommerce #content div.product div.thumbnails.columns-4 a, .woocommerce div.product div.thumbnails.columns-4 a,
.woocommerce-page #content div.product div.thumbnails.columns-4 a, .woocommerce-page div.product div.thumbnails.columns-4 a {
	margin-right: 2.6666%;
	width: 23%;
}
.woocommerce #content div.product div.thumbnails.columns-3 a, .woocommerce div.product div.thumbnails.columns-3 a,
.woocommerce-page #content div.product div.thumbnails.columns-3 a, .woocommerce-page div.product div.thumbnails.columns-3 a {
	margin-right: 3.5%;
	width: 31%;
}
.woocommerce #content div.product div.thumbnails a:before, .woocommerce div.product div.thumbnails a:before, .woocommerce-page #content div.product div.thumbnails a:before, .woocommerce-page div.product div.thumbnails a:before {
	content:' ';
	@include abs-cover;
	@include transition-all;
}
.woocommerce #content div.product div.thumbnails a:hover:before, .woocommerce div.product div.thumbnails a:hover:before, .woocommerce-page #content div.product div.thumbnails a:hover:before, .woocommerce-page div.product div.thumbnails a:hover:before {
	background-color:rgba(255,255,255, 0.4);
}
.woocommerce #content div.product div.thumbnails a.first, .woocommerce div.product div.thumbnails a.first, .woocommerce-page #content div.product div.thumbnails a.first, .woocommerce-page div.product div.thumbnails a.first {
    clear: none;
}
.woocommerce #content div.product div.thumbnails a.last, .woocommerce div.product div.thumbnails a.last, .woocommerce-page #content div.product div.thumbnails a.last, .woocommerce-page div.product div.thumbnails a.last {
    margin-right: 0;
}
.woocommerce #content div.product div.thumbnails a:nth-child(4n+1), .woocommerce div.product div.thumbnails a:nth-child(4n+1), .woocommerce-page #content div.product div.thumbnails a:nth-child(4n+1), .woocommerce-page div.product div.thumbnails a:nth-child(4n+1) {
	clear:both;
}

.woocommerce div.product div.images .flex-control-thumbs li img {
	@include transition-property(opacity);
}

div.pp_woocommerce .pp_arrow_next, div.pp_woocommerce .pp_arrow_previous {
	margin-top:4px;
}

.pswp {
	z-index: 10000;
}


/* Product summary */
.woocommerce, .woocommerce-page {
	#content div.product div.summary,
	div.product div.summary {
		margin-bottom: 6.5em;
		@include border-box;
	}
	&.sidebar_show {
		#content div.product div.summary,
		div.product div.summary {
			width: 100%;
			float: none;
			padding-left: 0;
			padding-right: 0;
		}
	}
	&.sidebar_hide {
		#content div.product div.summary,
		div.product div.summary {
			width: calc( 100% - var(--theme-var-single-product-gallery-width) );
			padding-left: 60px;
			float: right;
		}
	}
	#content div.product div.summary:after,
	div.product div.summary:after {
		content:' ';
		float:none;
		@include clear;
	}
}

.single-product div.product .woocommerce-tabs ul.wc-tabs {
	li a {
		color: var(--theme-color-alter_dark);
		background-color: var(--theme-color-alter_bg_color);
	}
	li:not(.active) a:hover,
	li.active a {
		color: var(--theme-color-alter_dark);
		background-color: transparent;
		border-color: var(--theme-color-alter_dark);
	}
}

.single-product div.product .woocommerce-tabs .panel {
	color: var(--theme-color-text);
}

/* Additional info */
.woocommerce, .woocommerce-page {
	div.product {
		div.summary .woocommerce-product-details__additional-information,
		.woocommerce-stack-additional_information {
			h2 {
				display: none;
			}
			table, th, td {
				background-color: transparent !important;
				text-transform: none;
				padding: 0;
				border: none;
				width: auto;
				font-weight: inherit;
				font-style: normal;
			}
			th {
				&:after {
					content: ':';
				}
				padding-right: 1em;
			}
			p {
				padding: 0;
			}
		}
	}
}


/* Meta: SKU, tags, categories, ID */
.woocommerce .product_meta span {
	display:block;
	font-weight: 700;
	font-size: 16px;
	line-height: 1.3em;
	color: var(--theme-color-text_dark);
	span {
		display: inline;
	}
	+ span {
		margin-top: 10px;
	}
	> a,
	> span {
		letter-spacing: 0;
		color: var(--theme-color-text);
		font-size: 15px;
		font-weight: 400;
	}
	a:hover {
		color: var(--theme-color-text_link);
	}
}

.woocommerce div.product .summary .stock {
	font-size: 19px;
	line-height: 24px;
	font-weight: 500;
	text-decoration: none;
	text-transform: none;
	letter-spacing: 0;
	display: inline-block;
	color: var(--theme-color-text_dark);
	position: relative;
	margin-bottom: 40px;
	&:after {
		content: "";
		display: block;
		height: 1px;
		width: 100%;
		margin-top: 5px;
		border-bottom: 1px solid var(--theme-color-text_link);
		@include box-shadow(0 9px 16px rgba(0, 0, 0, 0.2));
	}
}

/* Add to cart */
.woocommerce div.product form.cart, .woocommerce #content div.product form.cart, .woocommerce-page div.product form.cart, .woocommerce-page #content div.product form.cart {
	padding: 0;
	margin-bottom: 44px;
}
.single_product_bottom_bar_sticky div.quantity,
.woocommerce div.product form.cart div.quantity,
.woocommerce-page div.product form.cart div.quantity,
.woocommerce .shop_table.cart div.quantity,
.woocommerce-page .shop_table.cart div.quantity {
	margin: 0 10px 0 0;
	@include box(130px, 55px);
	position: relative;	
	span {
		display: block;
		@include abs-rt;
		right: 1px;
		top: 1px;
		@include box(39px, 50%, 1.95em);
		text-align: left;
		cursor: pointer;
		padding-left: 5px;
		&:before {
			font-family: $theme_icons;
			font-weight: 400;
		}
	}
	span.q_dec {
		top: auto;
		bottom: 1px;
		border-top: none;
		line-height: 1.6em;
	}
	span.q_inc:before {
		content:'\e835';
	}
	span.q_dec:before {
		content:'\e828';
	}
	input[type="number"] {
		@include box(100%, 100%);
		padding: 0 48px 0 25px;
		text-align: left;
		font-size: 16px;
		font-weight: 400;
		color: var(--theme-color-input_text);
		border: 1px solid var(--theme-color-input_bd_color) !important;
		@include border-radius(0);
		-moz-appearance: textfield;
		appearance: textfield;
	}
	input[type="number"]::-webkit-inner-spin-button,
	input[type="number"]::-webkit-outer-spin-button {
		-webkit-appearance: none;
		margin: 0;
	}
}
.woocommerce .shop_table.cart div.quantity, .woocommerce-page .shop_table.cart div.quantity {
	margin: 0;
	width: 7em;
	font-size: 1rem;
}

/* Grouped product */
.woocommerce div.product form.cart .group_table {
	margin-bottom: 1.8em;
}
.woocommerce div.product form.cart .group_table td {
	padding: 1.8em 1em;
	vertical-align: middle;
	font-size: 0.9em;
	.stock {
		font-size: 0.9em;
		margin: 0;
		display: table-cell;
		&:after {
			margin-top: 2px;
		}
	}
}


/* Product variations */
.woocommerce div.product form.cart .variations {
	margin-bottom: 34px;
	.select_container {
		max-width: 300px;
	}
	th,
	td {
		display: block;
		width: 100%;
		@include box-sizing(border-box);
		padding: 0 0 13px;
		background-color: transparent;
		text-align: left;
		line-height: 1.2em;
	}
	tr:last-child td.value {
		padding-bottom: 0;
	}
}
.woocommerce div.product form.cart .variations tr + tr .label {
	padding: 17px 0 13px 0;
}
.woocommerce div.product form.cart .variations .label {
	font-weight: 700;
	font-size: 16px;
	line-height: 1.2em;
	vertical-align: middle;
	color: var(--theme-color-text_dark);
}
.woocommerce div.product form.cart .variations label {
	font-weight: 700;
}
.woocommerce div.product form.cart .reset_variations {
	font-style: italic;
	font-size: 1em;
	letter-spacing: 0;
}
.woocommerce-variation-price {
	margin: 0;
}
.woocommerce-variation-price .price {
	padding-bottom: 25px;
	display: inline-block;
}
.woocommerce td.product-name dl.variation dd, 
.woocommerce td.product-name dl.variation dt {
	@include font(14px, 1.25em,  var(--theme-font-p_font-weight));
	padding: 0;
	margin: 0;
	color: var(--theme-color-text);
	* {
		color: inherit;
	}
}
.woocommerce td.product-name dl.variation dt {
	padding-top: 0.4em;
	padding-right: 0.4em;
}
.woocommerce td.product-name dl.variation dd {
	padding-top: 0.4em;
}
.woocommerce .reset_variations {
	display: none !important;
}


/* Wishlist and compare */
.woocommerce .product .summary > .yith-wcwl-add-to-wishlist {
	float:left;
	width: auto;
	margin-top:0;
	margin-bottom: 2em;
}
.woocommerce .product .summary > .compare {
	float:left;
	margin-bottom: 2em;
	margin-right: 2em;
}
.woocommerce .product .summary div.woocommerce-tabs + .compare,
.woocommerce .product .summary div.woocommerce-tabs + .compare + .yith-wcwl-add-to-wishlist,
.woocommerce .product .summary div.woocommerce-product-gallery__image + .compare,
.woocommerce .product .summary div.woocommerce-product-gallery__image + .compare + .yith-wcwl-add-to-wishlist {
	margin-top: 2em;
	margin-bottom: 0;
}

.woocommerce .product .yith-wcwl-add-to-wishlist {
	margin: 0;
}
.woocommerce .product .compare:before,
.woocommerce .product .yith-wcwl-add-to-wishlist .add_to_wishlist:before,
.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistaddedbrowse > a:before,
.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistexistsbrowse > a:before {
	content: '\e8a8';
	font-family: $theme_icons;
	margin-right:0.2em;
}
.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistaddedbrowse > a:before {
	content: '\e8aa';
}
.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistexistsbrowse > a:before {
	content: '\e8aa';
}
.woocommerce .product .compare:before {
	content: '\e8e7';
	margin-right:0.5em;
}

.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistaddedbrowse,
.woocommerce .product .yith-wcwl-add-to-wishlist .yith-wcwl-wishlistexistsbrowse {
	@include flex;
	@include flex-direction(row);
	@include flex-justify-content(center);
	@include flex-align-items(flex-start);
}
.woocommerce .product .yith-wcwl-add-to-wishlist .feedback,
.woocommerce .product .yith-wcwl-add-to-wishlist .feedback {
	order: 2;
	margin: 0 0 0 0.5em;
	font-size: 0.923em;
}
.woocommerce .product .yith-wcwl-add-to-wishlist .feedback:before,
.woocommerce .product .yith-wcwl-add-to-wishlist .feedback:before {
	content: '(';
}
.woocommerce .product .yith-wcwl-add-to-wishlist .feedback:after,
.woocommerce .product .yith-wcwl-add-to-wishlist .feedback:after {
	content: ')';
}

.woocommerce .product .summary ~ .yith-wcwl-add-to-wishlist {
	margin-top: 2em;
}

.woocommerce ul.products li.product .yith-wcwl-add-to-wishlist .feedback {
	display: none;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image > .yith-wcwl-add-to-wishlist {
	display: none;
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist {
	position: static;
	left: auto;
	top: auto;
	margin: 0;
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist i,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .yith-wcwl-icon {
	display: none;
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .feedback + a,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .add_to_wishlist,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .disabled_item,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith-wcwl-add-to-wishlist .open-pretty-photo {
	font-size: 1em;
}

.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap {
	@include abs-lt(1em, 1em, 2000);
	@include translateX(-60%);
	@include transition-properties(transform,opacity);
	opacity: 0;
	border: 1px solid var(--theme-color-extra_bd_color);
	background-color: var(--theme-color-extra_bg_color);
}
.woocommerce .related.products ul.products li.product.add-to-wishlist-before_image .post_item .yith_buttons_wrap {
	top: -1em;
	@include translateX(-200%);
}
.woocommerce .related.products ul.products li.product.add-to-wishlist-before_image .post_item:hover .yith_buttons_wrap {
	@include translateX(-60%);
}
.mobile_layout.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap,
.woocommerce ul.products li.product.add-to-wishlist-before_image .post_item:hover .yith_buttons_wrap {
	@include translateX(0);
	opacity: 1;
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > :nth-child(n+1) {
	border-top: 1px dotted var(--theme-color-extra_bd_color);
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist {
	margin: 0;
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div {
	position: relative;
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div > img {
	@include abs-cc;
	margin: 0;
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > a,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div > a {
	display: block;
	position: relative;
	z-index: 2;
	@include square(2em);
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > a:before,
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div > a:before {
	@include abs-lt;
	@include square(2em);
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > .yith-wcwl-add-to-wishlist > div > span {
	display: none !important;
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a {
	color: var(--theme-color-extra_link);
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a:hover {
	color: var(--theme-color-extra_hover);
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a > .tooltip {
	display: inline-block;
	vertical-align: top;
	pointer-events: none;
	padding: 6px 10px;
	@include font(12px, 16px);
	@include abs-lt(100%, 0);
	margin-left: 10px;
	white-space: nowrap;
	@include translateX(20px);
	opacity: 0;
	@include transition-properties(transform,opacity);
	border-width: 0;
	color: var(--theme-color-extra_text);
	background-color: var(--theme-color-extra_bg_color);
	border-color: var(--theme-color-extra_bg_color);
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a > .tooltip:before {
	content: ' ';
	@include abs-lc(-7px);
	border-style: solid;
	border-width: 0 0 4px 7px;
	border-bottom-color: inherit;
	border-left-color: transparent !important;
	border-right-color: transparent !important;
	border-top-color: transparent !important;
}
.woocommerce ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a:hover > .tooltip {
	@include translateX(0);
	opacity: 1;
}
.woocommerce ul.products.columns-5 li.product.add-to-wishlist-before_image .yith_buttons_wrap .tooltip,
.woocommerce ul.products.columns-6 li.product.add-to-wishlist-before_image .yith_buttons_wrap .tooltip {
	padding: 3px 6px;
	@include font(10px, 14px);
}


.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap {
	border-color: var(--theme-color-alter_bd_color);
	background-color: var(--theme-color-alter_bg_color);
}
.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap > :nth-child(n+1) {
	border-color: var(--theme-color-alter_bd_color);
}
.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a {
	color: var(--theme-color-alter_link);
}
.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a:hover {
	color: var(--theme-color-alter_hover);
}
.woocommerce.single-product ul.products li.product.add-to-wishlist-before_image .yith_buttons_wrap a > .tooltip {
	color: var(--theme-color-alter_text);
	background-color: var(--theme-color-alter_bg_color);
	border-color: var(--theme-color-alter_bg_color);
}

.woocommerce ul.products li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap,
.woocommerce ul.products li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap {
	@include flex;
	@include flex-direction(row);
	@include flex-justify-content(center);
	@include flex-align-items(center);
}
.woocommerce ul.products li.product.add-to-wishlist-before_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist,
.woocommerce ul.products li.product.add-to-wishlist-after_add_to_cart .yith_buttons_wrap .compare + .yith-wcwl-add-to-wishlist {
	margin-left: 1em;
}

.woocommerce ul.products li.product.add-to-wishlist-before_add_to_cart .add_to_cart_wrap + .yith_buttons_wrap,
.woocommerce ul.products li.product.add-to-wishlist-after_add_to_cart .add_to_cart_wrap + .yith_buttons_wrap {
	margin-top: 1em;
}

.woocommerce ul.products.columns-4 li.product,
.woocommerce ul.products.columns-5 li.product,
.woocommerce ul.products.columns-6 li.product,
.woocommerce ul.products.columns-7 li.product,
.woocommerce ul.products.columns-8 li.product {
	&.add-to-wishlist-before_add_to_cart .yith_buttons_wrap,
	&.add-to-wishlist-after_add_to_cart .yith_buttons_wrap {
		@include flex-direction(column);

		.compare + .yith-wcwl-add-to-wishlist {
			margin-left: 0;
		}
	}
}


.woocommerce.yith-wcwl-form {
	.wishlist-title > h2 {
		margin: 0;
	}
	.hidden-title-form a.hide-title-form {
		vertical-align: top;
	}
	table.wishlist_table {
		font-size:1em;

		td.product-add-to-cart a {
			display:inline-block !important;
		}
	}

	.yith_wcwl_wishlist_footer {
		.yith-wcwl-share {
			margin: 0;
			float: none;
			@include flex;
			@include flex-direction(row);
			@include flex-justify-content(flex-start);
			@include flex-align-items(center);

			h4.yith-wcwl-share-title {
				font-size:1em;
				margin-right: 1em;
			}

			li a {
				min-width: 0;
				min-height: 0;
				@include square( 2em );
				@include border-radius(50%);
				color: var(--theme-color-alter_dark);
				background-color: var(--theme-color-alter_bg_color);
			}
			li a:hover {
				color: var(--theme-color-alter_link);
				background-color: var(--theme-color-alter_bg_hover);
			}
		}
	}
}

/* Product meta */
.woocommerce div.product .product_meta {
	clear:both;
}


/* Tabs */
.woocommerce div.product .woocommerce-tabs ul.tabs, .woocommerce #content div.product .woocommerce-tabs ul.tabs, .woocommerce-page div.product .woocommerce-tabs ul.tabs, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs {
	padding-left: 0;
	margin: 0 0 55px;
	&:before {
		border-width: 0;
	}
}
.woocommerce div.product .woocommerce-tabs ul.tabs li,
.woocommerce #content div.product .woocommerce-tabs ul.tabs li,
.woocommerce-page div.product .woocommerce-tabs ul.tabs li,
.woocommerce-page #content div.product .woocommerce-tabs ul.tabs li {
	background: transparent;
	border: none;
	padding: 3px 6px;
	margin: 0 -6px;
	@include box-shadow(none);
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active,
.woocommerce #content div.product .woocommerce-tabs ul.tabs li.active,
.woocommerce-page div.product .woocommerce-tabs ul.tabs li.active,
.woocommerce-page #content div.product .woocommerce-tabs ul.tabs li.active {
	background: transparent;
	border: none;
	@include border-sharp;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li:before, .woocommerce #content div.product .woocommerce-tabs ul.tabs li:before, .woocommerce-page div.product .woocommerce-tabs ul.tabs li:before, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs li:before,
.woocommerce div.product .woocommerce-tabs ul.tabs li:after, .woocommerce #content div.product .woocommerce-tabs ul.tabs li:after, .woocommerce-page div.product .woocommerce-tabs ul.tabs li:after, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs li:after {
	display:none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active a, .woocommerce #content div.product .woocommerce-tabs ul.tabs li.active a, .woocommerce-page div.product .woocommerce-tabs ul.tabs li.active a, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs li.active a {
    text-shadow: inherit;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a, .woocommerce #content div.product .woocommerce-tabs ul.tabs li a, .woocommerce-page div.product .woocommerce-tabs ul.tabs li a, .woocommerce-page #content div.product .woocommerce-tabs ul.tabs li a {
	font-weight: 700;
	padding: 21px;
	@include box-sizing(border-box);
	min-width: 278px;
	font-size: 13px;
	line-height: 16px;
	text-transform: uppercase;
	letter-spacing: 1px;
	border-top: 2px solid transparent;
	text-align: center;
}

.woocommerce div.product .woocommerce-tabs .panel, .woocommerce #content div.product .woocommerce-tabs .panel, .woocommerce-page div.product .woocommerce-tabs .panel, .woocommerce-page #content div.product .woocommerce-tabs .panel {
	border: none;
    margin: 0;
    padding: 0;
	display: none;
}
.woocommerce div.product .woocommerce-tabs h2, .woocommerce #content div.product .woocommerce-tabs h2, .woocommerce-page div.product .woocommerce-tabs h2, .woocommerce-page #content div.product .woocommerce-tabs h2 {
	margin:0 0 1em;
	@include font(25px, '', 700);
	line-height: 1.2em;
	letter-spacing: 0;
}
.woocommerce div.product .woocommerce-tabs h3, .woocommerce #content div.product .woocommerce-tabs h3, .woocommerce-page div.product .woocommerce-tabs h3, .woocommerce-page #content div.product .woocommerce-tabs h3 {
	font-size: 1.5385em;
	margin-bottom:0.25em !important;
	letter-spacing:1px;
}
.woocommerce div.product .woocommerce-tabs p, .woocommerce #content div.product .woocommerce-tabs p, .woocommerce-page div.product .woocommerce-tabs p, .woocommerce-page #content div.product .woocommerce-tabs p {
	margin: 0;
	+ p {
		margin-top: 0.5em;
	}
}
.woocommerce div.product .woocommerce-tabs #tab-description h2 {
	display: none;
}


/* Additional attributes */
.woocommerce table.shop_attributes {
	border-style: solid;
	border-color: var(--theme-color-bd_color);
	th, td {
		font-weight: 400;
		text-align: left;
		font-size: 15px;
		border-style: solid;
		border-color: var(--theme-color-bd_color);
	}
}
.woocommerce table.shop_attributes tr:nth-child(2n+1) > * {
	background-color: var(--theme-color-alter_bg_color_04);
}
.woocommerce table.shop_attributes tr:nth-child(2n) > *,
.woocommerce table.shop_attributes tr.alt > * {
	background-color: var(--theme-color-alter_bg_color_02);
}
.woocommerce table.shop_attributes th {
	font-size: 16px;
	font-weight: 700;
	color: var(--theme-color-text_dark);
}


/* Stars */
.woocommerce div.product .woocommerce-product-rating, .woocommerce-page div.product .woocommerce-product-rating {
	float: right;
	margin: 0;
	.star-rating {
		margin-top: 8px;
		margin-bottom: 8px;
	}
}
.woocommerce .woocommerce-product-rating .woocommerce-review-link, .woocommerce-page .woocommerce-product-rating .woocommerce-review-link {
	display: none;
}
.woocommerce .woocommerce-product-rating .star-rating,
.woocommerce-page .woocommerce-product-rating .star-rating {
	margin-top: 10px;
	margin-bottom: 4px;
	margin-right: 0;
}
.woocommerce .star-rating,
.woocommerce-page .star-rating {
	@include box(88px, 1.2em);
	margin-top:4px;
	margin-bottom:4px;
	font-size: 14px;
	letter-spacing: 4px;
}


/* Users reviews */
.woocommerce #reviews {
	display: block;
	margin-left: calc( -1 * var(--theme-var-grid_gap) / 2 );
	margin-right: calc( -1 * var(--theme-var-grid_gap) / 2 );
	overflow: visible;
}
.woocommerce #reviews #comments,
.woocommerce #comments + #review_form_wrapper {
	float: left;
	width: 50%;
	@include border-box;
	padding-left: calc( var(--theme-var-grid_gap) / 2 );
	padding-right: calc( var(--theme-var-grid_gap) / 2 );
}
.woocommerce #reviews #comments ol.commentlist {
	padding:0;
	font-style:inherit;
	font-weight:inherit;
}
.woocommerce #reviews #comments ol.commentlist ul.children {
	padding: 0;
	margin: 0 0 0 4em;
}
.woocommerce #reviews #comments ol.commentlist li {
	margin-bottom:0;
}
.woocommerce #reviews #comments ol.commentlist li + li,
.woocommerce #reviews #comments ol.commentlist ul.children {
	padding-top: 1.5em;
	margin-top: 1.5em;
	border-top: 1px solid var(--theme-color-bd_color);
}
.woocommerce .woocommerce-tabs .form-submit {
	display: block;
}
.woocommerce #reviews #comments ol.commentlist li img.avatar,
.woocommerce-page #reviews #comments ol.commentlist li img.avatar {
	background: none;
	border: none;
	padding: 0;
	position: static;
	width: 60px;
	float: left;
	margin: 0 20px 10px 0;
	@include border-radius(50%);
}
.woocommerce #reviews #comments ol.commentlist li .comment-text,
.woocommerce-page #reviews #comments ol.commentlist li .comment-text {
	margin: 0;
	padding: 0 0 24px;
	border: 0;
	position: relative;
	overflow: hidden;
	.star-rating {
		position: absolute;
		left: 0;
		bottom: 0;
		margin-bottom: 0;
	}
	.description {
		font-size: 15px;
	}
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p {
	margin: 0;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p + p, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p + p {
	margin-top: 0.3em;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p.meta {
	margin: -2px 10px 4px 0;
	display: inline-block;
	vertical-align: middle;
	color: var(--theme-color-alter_text);
	font-size: 12px;
	line-height: 20px;
	font-weight: 400;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta strong, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p.meta strong {
	color: var(--theme-color-text_dark);
	font-size: 17px;
	line-height: 23px;
	font-weight: 700;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta time, .woocommerce-page #reviews #comments ol.commentlist li .comment-text p.meta time {
	font-style: normal;
	letter-spacing:0;
}

.woocommerce .comment-form .comment-form-comment label,
.woocommerce .comment-form .comment-form-rating label,
.woocommerce .comment-form .comment-form-author label,
.woocommerce .comment-form .comment-form-email label {
	display: block;
	font-weight: 700;
	font-size: 1em;
	color: var(--theme-color-text_dark);
}
.woocommerce #review_form #respond .form-submit {
	margin-bottom: 0;
}
.woocommerce #review_form #respond,
.woocommerce-page #review_form #respond {
	input[type="text"],
	input[type="number"],
	input[type="email"],
	textarea {
		width: 100%;
		@include box-shadow(0 15px 15px -14px rgba(0, 0, 0, 0.018));
	}
}
.woocommerce #review_form #respond textarea, .woocommerce-page #review_form #respond textarea {
	height: 6em;
	min-height: 5em;
	overflow:auto;
}
.woocommerce #review_form #respond #reply-title {
	@include font(25px, 1.2em, 700);
	letter-spacing: 0;
	margin-bottom: 0.8em;
	display: inline-block;
	color: var(--theme-color-text_dark);
}
.woocommerce .comment-form .comment-form-rating,
.woocommerce #review_form #respond p {
	margin: 0 0 1.4em;
}

.woocommerce #review_form #respond .form-submit {
	margin-top: 40px;
}
.woocommerce #review_form #respond p.comment-form-rating,
.woocommerce #review_form #respond p.comment-form-rating .stars {
	margin-bottom: 0;
}
.woocommerce #review_form #respond p.stars {
	margin-bottom: 0;
	margin-top: 7px;
}

.woocommerce .comment-form .comment-form-author label,
.woocommerce .comment-form .comment-form-email label {
	display: block;
}


/* Related products */
.single-product .related,
.single-product .upsells {
	margin-top: 4.4em;
	clear: both;
	ul.products {
		margin-bottom: -25px;
	}
}
.single-product .related h2,
.single-product .upsells h2 {
	margin-bottom: 55px;
	text-align: left;
	margin-top: 0;
	margin-left: -1px;
}
.single-product ul.products li.product .post_item {
	padding: 0;
	position:relative;
	.price *,
	.price {
		color: var(--theme-color-alter_text);
	}
}
.single-product .footer_copyright_wrap {
	outline: none;
}
.single-product .footer_logo_wrap + .footer_copyright_wrap,
.single-product .footer_socials_wrap + .footer_copyright_wrap,
.single-product .footer_menu_wrap + .footer_copyright_wrap {
	margin-top:0;
}

.woocommerce .related ul li.product, .woocommerce .related ul.products li.product, .woocommerce .upsells.products ul li.product, .woocommerce .upsells.products ul.products li.product, .woocommerce-page .related ul li.product, .woocommerce-page .related ul.products li.product, .woocommerce-page .upsells.products ul li.product, .woocommerce-page .upsells.products ul.products li.product {
	border:none;
	box-shadow: none;
}


/* Cross-sells */
.woocommerce .cart-collaterals,
.woocommerce-page .cart-collaterals {
	@include flex;
	@include flex-direction(column);
	@include flex-align-items(flex-end);

	.cross-sells {
		order:2;
		float:none;
		width: 100%;
	}
	.cart_totals {
		order:1;
		float:none;
	}
}

/* Group Table */
.woocommerce div.product form.cart .group_table td.woocommerce-grouped-product-list-item__label a,
.woocommerce-page div.product form.cart .group_table td.woocommerce-grouped-product-list-item__label a {
	font-weight: 500;
}
.woocommerce div.product form.cart .group_table td.woocommerce-grouped-product-list-item__price span.amount,
.woocommerce-page div.product form.cart .group_table td.woocommerce-grouped-product-list-item__price span.amount {
	font-weight: 400;
}

/* Widgets decoration
---------------------------------------------------------------*/

/* Cart & Products list */
.woocommerce a.remove {
	margin-top: 0.5em;
	text-align: center;
	position: relative;
	overflow: hidden;
	@include box(1.2em, 1.2em, 1.2em);
	text-indent: -100px;
	font-size: 9px !important;
	font-weight: 400 !important;
	@include border-radius(0);
	&:before {
		display: none !important;
	}
	&:after {
		position: absolute;
		top: 0;
		left: 0;
		z-index: 1;
		content: '\e9e1';
		font-family: $theme_icons;
		line-height: inherit;
		text-align: center;
		border: none;
		text-indent: 0;
		width: 100%;
		height: 100%;
		color: var(--theme-color-alter_light);
		@include transition(color .3s ease);
	}
	&:hover:after {
		color: var(--theme-color-text_link);
	}
}
.woocommerce a.remove,
.woocommerce a.remove:hover {
	color: #e05100 !important;
	background-color:transparent !important;
}
.woocommerce table.shop_table {
	border-collapse:collapse;
	margin-bottom: 2em;
	border: none;
	@include border-radius(0);
}
.woocommerce table.shop_table td {
	border-color: var(--theme-color-bd_color) !important;
	background: transparent;
}
.woocommerce table.shop_table th {
	border-color: var(--theme-color-alter_bg_color) !important;
	background-color: var(--theme-color-alter_bg_color) !important;
}
.woocommerce table.shop_table tfoot th,
.woocommerce-page table.shop_table tfoot th {
	color: var(--theme-color-text_dark);
	border-color: transparent !important;
	background-color: transparent;
}
.woocommerce table.shop_table tr:first-child th {
	border-style: solid;
	border-width: 0 0 1px 0 !important;
}
.woocommerce table.shop_table tr:nth-child(n+1) th:first-child,
.woocommerce table.shop_table tr:nth-child(n+1) td:first-child,
.woocommerce table.shop_table td {
	border-style: solid;
	border-width: 1px 0;
}
.woocommerce table.account-orders-table.shop_table tbody tr:first-child td:first-child {
	border-top: 1px solid;
}
.woocommerce table.account-orders-table.shop_table tr:nth-child(n+1) th:first-child,
.woocommerce table.account-orders-table.shop_table tr:nth-child(n+1) td:first-child,
.woocommerce table.account-orders-table.shop_table td {
    border-width: 1px 0;
}
.woocommerce .shop_table p {
	margin: 0;
}
.woocommerce .shop_table a.remove {
	margin: 0;
	font-weight: 400;
}
.woocommerce ul.product_list_widget li,
.woocommerce-page ul.product_list_widget li {
	padding: 10px 0 1em;
	overflow:hidden;
}
.woocommerce.widget_shopping_cart ul.cart_list li {
	padding: 10px 0 20px 0;
	overflow:hidden;
}
.woocommerce ul.cart_list li dl:after,
.woocommerce ul.product_list_widget li dl:after {
	clear: none;
}
.woocommerce ul.cart_list li:before,
.woocommerce-page ul.cart_list li:before,
.woocommerce ul.product_list_widget li:before,
.woocommerce-page ul.product_list_widget li:before {
	display:none;
}
ul.cart_list li > b { // product from Booking Calendar
	color: var(--theme-color-text_dark);
}
.woocommerce ul.cart_list li > b,
.woocommerce ul.cart_list li a,
.woocommerce-page ul.cart_list li a,
.woocommerce ul.product_list_widget li a,
.woocommerce-page ul.product_list_widget li a {
	font-weight: 700;
	font-size: 17px;
}
.woocommerce .widget_shopping_cart .cart_list li a.remove,
.woocommerce.widget_shopping_cart .cart_list li a.remove {
	position: absolute;
	right: 0;
	top: 0;
	left: auto;
	margin: 0 !important;
}
.woocommerce ul.cart_list li,
.woocommerce-page ul.cart_list li,
.woocommerce ul.product_list_widget li,
.woocommerce-page ul.product_list_widget li {
	padding-top: 10px;
}
.woocommerce ul.cart_list li img,
.woocommerce-page ul.cart_list li img,
.woocommerce ul.product_list_widget li img,
.woocommerce-page ul.product_list_widget li img {
	float: left;
	margin: -10px 20px 10px 0;
	@include box-shadow(none);
	@include border-radius(0);
	width: 81px;
	height: 81px;
	object-fit: cover;
}
.woocommerce ul.cart_list li img,
.woocommerce-page ul.cart_list li img {
	margin-right: 20px;
}
.woocommerce ul.cart_list li dl,
.woocommerce-page ul.cart_list li dl,
.woocommerce ul.product_list_widget li dl,
.woocommerce-page ul.product_list_widget li dl {
	overflow: hidden;
	@include font(14px, 1.5em,  var(--theme-font-p_font-weight));
	margin-top: 4px;
	padding-left: 8px;
	border-left-width: 1px;
	border-color: var(--theme-color-bd_color);
}
.woocommerce ul.cart_list li dl dd,
.woocommerce ul.cart_list li dl dt,
.woocommerce ul.product_list_widget li dl dd,
.woocommerce ul.product_list_widget li dl dt {
	padding:0;
	margin:0;
}
.woocommerce ul.product_list_widget li dl dt,
.woocommerce-page ul.product_list_widget li dl dt {
	margin-right: 0.3em;
	font-weight: var(--theme-font-p_font-weight);
}
.woocommerce ul.product_list_widget li dl dt:before,
.woocommerce-page ul.product_list_widget li dl dt:before {
	content:' ';
	display:block;
	@include box(100%, 0);
}
.woocommerce ul.cart_list li dl dd,
.woocommerce-page ul.cart_list li dl dd,
.woocommerce ul.product_list_widget li dl dd,
.woocommerce-page ul.product_list_widget li dl dd {
	margin-right: 2em;
}
.woocommerce.widget_shopping_cart .quantity,
.woocommerce-page.widget_shopping_cart .quantity,
.woocommerce .widget_shopping_cart .quantity,
.woocommerce-page .widget_shopping_cart .quantity {
	margin: 3px 0 0;
	display:inline-block;
	font-size: 18px;
	font-weight: 500;
}
.woocommerce .quantity input.qty,
.woocommerce-page .quantity input.qty,
.woocommerce #content .quantity input.qty,
.woocommerce-page #content .quantity input.qty {
	color: var(--theme-color-input_dark);
}
.woocommerce ul.cart_list li > .amount,
.woocommerce-page ul.cart_list li > .amount,
.woocommerce ul.product_list_widget li > .amount,
.woocommerce-page ul.product_list_widget li > .amount,
.woocommerce ul.cart_list li span .amount,
.woocommerce-page ul.cart_list li span .amount,
.woocommerce ul.product_list_widget li span .amount,
.woocommerce-page ul.product_list_widget li span .amount,
.woocommerce ul.cart_list li ins .amount,
.woocommerce-page ul.cart_list li ins .amount,
.woocommerce ul.product_list_widget li ins .amount,
.woocommerce-page ul.product_list_widget li ins .amount,
.woocommerce ul.cart_list li del,
.woocommerce-page ul.cart_list li del,
.woocommerce ul.product_list_widget li del,
.woocommerce-page ul.product_list_widget li del {
    @include font(18px, '', 500);
}

footer .product_list_widget li a + span.amount {
	margin-top: 10px;
	display: inline-block;
}

.woocommerce ul.cart_list li ins,
.woocommerce-page ul.cart_list li ins,
.woocommerce ul.product_list_widget li ins,
.woocommerce-page ul.product_list_widget li ins {
	text-decoration:none;
	font-style:normal;
}
.woocommerce ul.cart_list li .star-rating,
.woocommerce ul.product_list_widget li .star-rating {
	margin-bottom: 0;
}
.woocommerce .widget_shopping_cart .total, .woocommerce.widget_shopping_cart .total {
	border: none;
}
.woocommerce.widget_shopping_cart .total,
.woocommerce-page.widget_shopping_cart .total,
.woocommerce .widget_shopping_cart .total,
.woocommerce-page .widget_shopping_cart .total {
	font-size: 19px;
	font-weight: 700;
    padding: 4px 0 0;
	color: var(--theme-color-text_dark);
	strong {
		font-weight: 700;
	}
}
.woocommerce.widget_shopping_cart .total .amount,
.woocommerce-page.widget_shopping_cart .total .amount,
.woocommerce .widget_shopping_cart .total .amount,
.woocommerce-page .widget_shopping_cart .total .amount {
	@include font(19px, '', 700);
	color: var(--theme-color-text_link);
}
.woocommerce .widget_shopping_cart .buttons,
.woocommerce.widget_shopping_cart .buttons {
	margin-top: 33px;
}
.woocommerce .widget_shopping_cart .buttons a,
.woocommerce.widget_shopping_cart .buttons a {
	margin-right: 10px;
	margin-bottom: 10px;
	width: calc(50% - 5px);
	font-size: 15px;
	line-height: 18px;
	padding: 15px;
	text-align: center;
	display: inline-block;
	@include box-shadow(none);
	+ a {
		margin-left: 0 !important;
		margin-right: 0 !important;
	}
	&.checkout {
		border: 2px solid var(--theme-color-text_dark) !important;
		color: var(--theme-color-text_dark) !important;
		background: none !important;
		@include box-shadow(none !important);
		@include box-sizing(border-box);
		padding: 13px;
		&:hover {
			border: 2px solid var(--theme-color-text_link) !important;
			color: var(--theme-color-text_link) !important;
		}
	}
}



/* Active filters */
.woocommerce .widget_layered_nav_filters > ul > li {
	padding:0 0.625em 0.5em 0;
	display:block;
}
.woocommerce .widget_layered_nav_filters > ul > li:before {
	display:none;
}
.woocommerce .widget_layered_nav ul {
	padding-left: 1.2em;
}
.woocommerce .widget_layered_nav_filters > ul > li a,
.woocommerce .widget_layered_nav ul li.chosen a,
.woocommerce-page .widget_layered_nav ul li.chosen a {
	background-color: transparent;
	border:none;
	padding:0;
}
.widget_layered_nav ul li.chosen a {
	color: var(--theme-color-text_dark);
}


/* Average Rating */
.woocommerce .widget_rating_filter ul li .star-rating {
	vertical-align:middle;
}

/* Price filter */
.woocommerce .widget_price_filter .ui-slider .ui-slider-range,
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
	background-color: var(--theme-color-text_link3);
}
.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
	margin-bottom: 13px;
	margin-left: 0;
	margin-right: 0;
	height: 6px;
	background: var(--theme-color-alter_bg_hover);
	@include border-radius(0);
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
	@include border-round;
	@include box(12px, 12px);
	margin-left: -6px;
	top: -3px;
	opacity: 0;
}
.woocommerce .widget_price_filter .ui-slider-horizontal .ui-slider-range {
	height:6px;
	top: 0;
	@include border-radius(0);
}
.woocommerce .widget_price_filter .price_slider_amount {
	@include font(16px, 1.5em);
	text-align: left;
	font-weight: 400;
	@include flex;
	flex-direction: column-reverse;
	align-items: flex-start;
	.price_label {
		color: var(--theme-color-text_light);
	}
}
.woocommerce .widget_price_filter .price_slider_amount span {
	font-weight: 400;
}
.widget_price_filter .price_label span {
	color: var(--theme-color-text_light);
}
.woocommerce .widget_price_filter .price_slider_amount .button {
	float: none;
	position: relative;
	margin-top: 23px;
	@include box-shadow(none);
	&:after {
		content: '\e908';
		font-family: $theme_icons;
		font-weight: 400;
		display: inline-block;
		margin: 0 -5px 0 26px;
	}
}

/* Product search */
/* This widget's styles see in the style.css in the section 'Widget: Search' */
.widget_product_search form:after {
	color: var(--theme-color-input_light);
}
.widget_product_search form:hover:after {
	color: var(--theme-color-input_dark);
}

/* Rating filter */
.woocommerce.widget_rating_filter ul li:before {
	display:none !important;
}


/* Product title in widgets */
aside.woocommerce .product-title,
aside.woocommerce .mini_cart_item > a:not(.remove) {
	display:block;
	line-height:1.3em;
}

/* Results */
.search-no-results {
	&.woocommerce,
	&.woocommerce-page {
		.woocommerce-message:last-child,
		.woocommerce-info:last-child {
			margin: 0;
			padding: 20px;
		}
	}
}

/* Currency Switcher */
.widget.WOOCS_CONVERTER .woocs_converter_shortcode > * {
	vertical-align:middle;
}
.widget.WOOCS_CONVERTER .woocs_converter_shortcode .select_container {
	display: inline-block;
	width: 43%;
	margin-right:0.3em;
}
.widget.WOOCS_CONVERTER .woocs_converter_shortcode .select_container + .select_container {
	margin-left:0.3em;
	margin-right:0;
}
.widget.WOOCS_CONVERTER .button {
	margin-top: 1em;
}

.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container-single .chosen-single {
	height: auto;
	padding: 1em 0 1em 1em;
	@include box-shadow(none);
	color: var(--theme-color-input_text);
	background: var(--theme-color-input_bg_color);
}
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container-single .chosen-single:hover {
	color: var(--theme-color-input_dark);
	background: var(--theme-color-input_bg_hover);
}
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container-single .chosen-single div {
	background: none;
}
.widget.WOOCS_SELECTOR .chosen-container-single .chosen-drop {
	margin-top: 1px;
	@include box-shadow(none);
	@include border-radius(4px);
}
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-drop {
	color: var(--theme-color-input_dark);
	background: var(--theme-color-input_bg_hover);
	border-color: var(--theme-color-input_bd_hover);
}
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-results li {
	background-position: right center !important;
	color: var(--theme-color-input_dark);
}
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-results li:hover,
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-results li.highlighted,
.widget.WOOCS_SELECTOR .woocommerce-currency-switcher-form .chosen-container .chosen-results li.result-selected {
	color: var(--theme-color-alter_link) !important;
}


/* YITH Second image */
.yith_magnifier_zoom_wrap .yith_magnifier_zoom_magnifier {
	border-color: var(--theme-color-bd_color);
}

/* YITH Compare */
.yith-woocompare-widget ul.products-list {
	padding-left: 0;
}
.yith-woocompare-widget ul.products-list li:before {
	display: none;
}
.yith-woocompare-widget ul.products-list li .remove {
	margin-top: 0;
}
.yith-woocompare-widget a.compare {
	float:left;
}
.yith-woocompare-widget a.clear-all {
	display:inline-block;
	float:right;
	color: var(--theme-color-inverse_link);
	background-color: var(--theme-color-alter_link);
}
.yith-woocompare-widget a.clear-all:hover {
	color: var(--theme-color-inverse_hover);
	background-color: var(--theme-color-alter_hover);
}



/* Cart
--------------------------------------------------------------------- */
.woocommerce .woocommerce-cart-form table.shop_table_responsive tr.woocommerce-cart-form__cart-item td {
	vertical-align: middle;
}

div.product form.cart div.quantity > label {
	outline: none;
}

.woocommerce .quantity input.qty, .woocommerce #content .quantity input.qty, .woocommerce-page .quantity input.qty, .woocommerce-page #content .quantity input.qty {
	font-weight: 400;
	padding-left:0.75em;
	padding-right:0;
	width: 4em;
	@include font(0.8421em, 1em);
}

#add_payment_method table.cart img, .woocommerce-cart table.cart img, .woocommerce-checkout table.cart img {
	width: 40px;
}
.woocommerce table.cart .product-name, .woocommerce #content table.cart .product-name, .woocommerce-page table.cart .product-name, .woocommerce-page #content table.cart .product-name {
	text-align:left !important;
}
.woocommerce table.cart th, .woocommerce #content table.cart th, .woocommerce-page table.cart th, .woocommerce-page #content table.cart th {
	font-size: 17px;
	line-height: 1.3em;
	font-weight: 700;
	color: var(--theme-color-text_dark);
}
.woocommerce table.cart th, .woocommerce #content table.cart th, .woocommerce-page table.cart th, .woocommerce-page #content table.cart th,
.woocommerce table.cart td, .woocommerce #content table.cart td, .woocommerce-page table.cart td, .woocommerce-page #content table.cart td {
	padding: 12px;
	text-align: left;
}

.woocommerce table.cart td.actions,
.woocommerce-page table.cart td.actions,
.woocommerce #content table.cart td.actions,
.woocommerce-page #content table.cart td.actions {
	border-bottom: none !important;
	padding-top:1em;
}
.woocommerce table.cart td.actions .coupon .input-text,
.woocommerce-page table.cart td.actions .coupon .input-text,
.woocommerce #content table.cart td.actions .coupon .input-text,
.woocommerce-page #content table.cart td.actions .coupon .input-text {
	width: 10.7em;
	margin-right:0.3em;
}
.woocommerce table.cart td.actions .coupon + .button,
.woocommerce-page table.cart td.actions .coupon + .button,
.woocommerce #content table.cart td.actions .coupon + .button,
.woocommerce-page #content table.cart td.actions .coupon + .button {
	float: right;
}
.woocommerce table.shop_table tfoot th,
.woocommerce-page table.shop_table tfoot th {
	text-align:center;
}
.woocommerce .cart-collaterals h2,
.woocommerce-page .cart-collaterals h2 {
	@include font(24px, 1.3em, 700);
	margin: 2.2em 0 1em;
}
.woocommerce table.shop_table .cart-subtotal .amount, .woocommerce-page table.shop_table .cart-subtotal .amount,
.woocommerce table.shop_table .shipping td, .woocommerce-page table.shop_table .shipping td {
	color: var(--theme-color-text_dark);
}
.woocommerce table.cart td+td a,
.woocommerce-page table.cart td+td a,
.woocommerce #content table.cart td+td a,
.woocommerce-page #content table.cart td+td a,
.woocommerce table.cart td+td span,
.woocommerce-page table.cart td+td span,
.woocommerce #content table.cart td+td span,
.woocommerce-page #content table.cart td+td span {
	color: var(--theme-color-text_dark);
}
.woocommerce table.cart td+td a:hover,
.woocommerce-page table.cart td+td a:hover,
.woocommerce #content table.cart td+td a:hover,
.woocommerce-page #content table.cart td+td a:hover {
	color: var(--theme-color-text_link);
}
#add_payment_method table.cart td.actions .coupon .input-text,
.woocommerce-cart table.cart td.actions .coupon .input-text,
.woocommerce-checkout table.cart td.actions .coupon .input-text {
	border-color: var(--theme-color-input_bd_color);
}

.woocommerce table.cart td.actions .input-text, .woocommerce-page table.cart td.actions .input-text {
	width: 100px;
}

.woocommerce ul#shipping_method li {
	padding-left:0;
	text-indent:0;
	margin: 0.1em 0;
}

.woocommerce .cart-collaterals .woocommerce-shipping-calculator .shipping-calculator-form,
.woocommerce-page .cart-collaterals .woocommerce-shipping-calculator .shipping-calculator-form {
	margin: 1em 0;
}
.woocommerce .cart-collaterals .shipping_calculator .shipping-calculator-button:after,
.woocommerce-page .cart-collaterals .shipping_calculator .shipping-calculator-button:after {
	@include font(1em, '', 400);
}

 #add_payment_method .wc-proceed-to-checkout a.checkout-button,
 .woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
 .woocommerce-checkout .wc-proceed-to-checkout a.checkout-button {
	 display: block;
 }

.woocommerce-shipping-calculator .select2-container.select2-container--default .select2-selection .select2-selection__arrow {
	display: none;
}
.woocommerce-shipping-calculator .select_container:before {
	top: 2px;
	right: 2px;
	bottom: 2px;
}


/* Scrollbar decoration */
.sc_layouts_cart_widget ul.product_list_widget {
	overflow-x: hidden;
	overflow-y: auto;
	// Firefox
	scrollbar-width: thin;
	// WebKit-based browsers
	&::-webkit-scrollbar {
		width: 6px;
	}
	&::-webkit-scrollbar-track {
		background: var(--theme-color-alter_dark);
	}
	&::-webkit-scrollbar-thumb {
		background-color: var(--theme-color-alter_bd_color);
	}
}


/* Login */
.woocommerce-form-login {
	p:not([class]) {
		text-align: left;
	}
	.form-row {
		margin-bottom: 25px !important;
		text-align: left;
		.woocommerce-form-login__rememberme {
			display: block;
		}
	}
	.lost_password {
		text-align: left;
		font-size: 16px;
	}
}
.woocommerce-checkout .woocommerce-form-login {
	max-width: 70%;
	margin-left: auto;
	margin-right: auto;
}
/* Checkout
--------------------------------------------------------------------------*/
.woocommerce form .form-row {
	padding:0;
	margin-bottom: 47px;
}
.woocommerce form .form-row label, .woocommerce-page form .form-row label {
    line-height: 1.5em;
	font-size: 16px;
	font-weight: 700;
	margin-bottom: 15px;
	color: var(--theme-color-text_dark);
}
.woocommerce form .form-row label.inline {
	margin-left: 1em;
}
.woocommerce form .form-row input.input-text, .woocommerce form .form-row textarea {
	line-height:1.4855em;
	@include box-shadow(0 15px 15px -14px rgba(0, 0, 0, 0.018));
}
#commentform input.input-text,
#commentform textarea,
.woocommerce .select2-selection {
	@include box-shadow(0 15px 15px -14px rgba(0, 0, 0, 0.018));
}
.woocommerce-checkout.checkout h3 {
	margin-bottom: 38px;
	margin-top: 0;
}
.woocommerce .checkout input[type="checkbox"] {
	display:inline;
	position: static !important;
	clip: auto;
}
.woocommerce .checkout .col-2 h3#ship-to-different-address label, .woocommerce-page .checkout .col-2 h3#ship-to-different-address label {
	display:inline-block;
}
.woocommerce form .form-row input.input-text, .woocommerce form .form-row textarea, .woocommerce-page form .form-row input.input-text, .woocommerce-page form .form-row textarea {
	font-weight:400;
}
.woocommerce .checkout table.shop_table {
	margin-bottom: 3em;
}
.woocommerce .checkout table.shop_table th, .woocommerce .checkout table.shop_table td {
	text-align:left;
}
.woocommerce .checkout table.shop_table tfoot th {
	text-align:right;
}
.woocommerce .checkout table.shop_table tfoot td,
.woocommerce .checkout table.shop_table tfoot th {
	font-weight: 400;
}
.woocommerce table.shop_table .cart-subtotal .amount, .woocommerce-page table.shop_table .cart-subtotal .amount,
.woocommerce table.shop_table .shipping td, .woocommerce-page table.shop_table .shipping td {
	font-weight:400;
}
.woocommerce .cart-collaterals .shipping_calculator, .woocommerce-page .cart-collaterals .shipping_calculator {
    clear: none;
    float: left;
	margin-bottom:30px;
}
.woocommerce .checkout #order_review,
.woocommerce-page .checkout #order_review {
	margin-bottom:3em;
}
.woocommerce .checkout #order_review .order-total .amount,
.woocommerce-page .checkout #order_review .order-total .amount {
	letter-spacing: 0;
}
.woocommerce .checkout #order_review .payment_methods li,
.woocommerce-page .checkout #order_review .payment_methods li {
	list-style:none;
}
.woocommerce .checkout #order_review .payment_methods li label,
.woocommerce-page .checkout #order_review .payment_methods li label {
	display:inline-block;
}

#add_payment_method #payment ul.payment_methods li img,
.woocommerce-checkout #payment ul.payment_methods li img {
	margin: -5px 0.5em 0;
	max-height: 30px;
}
#add_payment_method #payment div.payment_box:before,
.woocommerce-cart #payment div.payment_box:before,
.woocommerce-checkout #payment div.payment_box:before {
	border-color: transparent;
}
.woocommerce-checkout #payment div.payment_box:after {
	top:0;
}
#add_payment_method #payment,
.woocommerce-cart #payment,
.woocommerce-checkout #payment {
	background-color: transparent;
}
#add_payment_method #payment .payment_method_paypal .about_paypal,
.woocommerce-cart #payment .payment_method_paypal .about_paypal,
.woocommerce-checkout #payment .payment_method_paypal .about_paypal {
	line-height:1.7em;
	float: none;
}

.woocommerce ul.order_details {
	padding-left: 0;
}
.woocommerce .order_details.woocommerce-thankyou-order-details {
	padding: 25px;
	color:var(--theme-color-alter_text);
	background-color:var(--theme-color-alter_bg_color);
	text-transform: none;
	.amount,
	.amount * {
		color:var(--theme-color-alter_dark);
	}
}
.woocommerce .order_details.woocommerce-thankyou-order-details li strong {
	font-weight:400;
	margin-top: 3px;
	line-height: 1.3em;
	color:var(--theme-color-alter_dark);
}

.woocommerce .shop_table.order_details th,
.woocommerce .shop_table.customer_details th {
	text-align: left;
}
.woocommerce .shop_table.order_details tfoot th {
	text-align:right;
}
.woocommerce .shop_table.order_details td.product-name strong {
	font-style:normal;
}
.woocommerce .order_details li,
.woocommerce-page .order_details li {
    @include font(1em, 1em);
	list-style:none;
}
.woocommerce .order_details li strong,
.woocommerce-page .order_details li strong {
	.amount {
		color: var(--theme-color-text_dark);
	}
	color: var(--theme-color-text_dark);
}

.woocommerce .woocommerce-customer-details address {
	@include border-box;
}

.woocommerce form .form-row #createaccount {
	margin-right: 4px;
	vertical-align:middle;
}
.woocommerce form .form-row input[type="radio"] + label:before,
.woocommerce form .form-row input[type="checkbox"] + label:before {
	top: 10px;
}

.woocommerce form .woocommerce-checkout-payment .wpgdprc-checkbox {
	label {
		position: relative;
		@include font(14px, 22px !important, 400);
		margin-bottom: 0;
		padding-left: 1.8em;
		display: inline-block;
		vertical-align: top;
		color: var(--theme-color-text);
		abbr.required {
			color: #FF5B4A !important;
		}
	}
	&.woocommerce-invalid label {
		color: var(--theme-color-text) !important;
	}
	&.woocommerce-validated label {
		color: var(--theme-color-text_dark);
	}
}

.woocommerce-form-login  .woocommerce-form__input-checkbox,
.woocommerce-terms-and-conditions-wrapper .woocommerce-form__input-checkbox {
	display: inline;
}
.woocommerce-terms-and-conditions-wrapper p {
	margin-bottom: 0.5em;
}
.woocommerce-form-login label.woocommerce-form-login__rememberme,
.woocommerce-terms-and-conditions-wrapper label {
	padding-left: 1.15em;
	position: relative;
}
.woocommerce-form-login label.woocommerce-form-login__rememberme {
	margin-bottom: 20px;
	padding-left: 1.8em;
	position: relative;
	@include font(14px !important, 22px !important, 400 !important);
	color: var(--theme-color-text) !important;
}
.woocommerce-form-login label.woocommerce-form-login__rememberme input[type="checkbox"],
.woocommerce-terms-and-conditions-wrapper label input[type="checkbox"] {
	position: static !important;
	clip: auto;
	width: 0;
	outline: 0 !important;
	-webkit-appearance: none;
	-moz-appearance: none;
}
.woocommerce-form-login label.woocommerce-form-login__rememberme input[type="checkbox"]:before,
.woocommerce-terms-and-conditions-wrapper label input[type="checkbox"]:before {
	content: '';
	font-family: $theme_icons;
	display: block;
	text-align: center;
	border: 1px solid var(--theme-color-bd_color);
	font-size: 7px;
	@include box(16px, 16px, 15px);
	@include abs-lt(0, 0.45em);
	@include border-box;
	@include border-radius(4px);
	color: var(--theme-color-text_dark);
	cursor: pointer;
	@include transition(all .3s ease);
}
.woocommerce-form-login label.woocommerce-form-login__rememberme:hover input[type="checkbox"]:before {
	border-color: var(--theme-color-text_dark) !important;
}
.woocommerce-form-login label.woocommerce-form-login__rememberme input[type="checkbox"]:checked:before,
.woocommerce-terms-and-conditions-wrapper label input[type="checkbox"]:checked:before {
	content: '\e9f6';
}
.ua_ie .woocommerce-form-login label.woocommerce-form-login__rememberme,
.ua_ie .woocommerce-terms-and-conditions-wrapper label {
	padding-left: 0;
}
.ua_ie .woocommerce-form-login input[type="checkbox"],
.ua_ie .woocommerce-terms-and-conditions-wrapper input[type="checkbox"] {
	width: auto;
}
.ua_ie .woocommerce-form-login input[type="checkbox"]:before,
.ua_ie .woocommerce-terms-and-conditions-wrapper input[type="checkbox"]:before {
	display: none;
}



/* My Account
--------------------------------------------------------------------------*/
.woocommerce form .form-row label.inline input[type="checkbox"] {
	display:inline;
	position: relative !important;
	clip: auto;
	top:2px;
}
.woocommerce-account h2,
.woocommerce-account .address .title h3 {
	margin: 1em 0 0.4em;
}
.woocommerce-MyAccount-content {
	.woocommerce-message,
	.woocommerce-info {
		margin: 0 0 20px 0;
		text-align: left;
	}
}
.woocommerce-MyAccount-navigation,
.woocommerce-MyAccount-content .woocommerce-Address-title a {
	@include font(1em, 1.3em, 500);
}
.woocommerce-account .woocommerce-MyAccount-navigation  {
	width: 20%;
	float: left;
	border-color: var(--theme-color-bd_color);
}
.woocommerce-MyAccount-navigation ul {
	padding: 0;
	margin:0;
	list-style-type:none;
}
.woocommerce-MyAccount-navigation ul li {
	padding:0;
	margin:0;
	border-color: var(--theme-color-bd_color);
}
.woocommerce-MyAccount-navigation ul li+li {
	border-top: 1px solid var(--theme-color-bd_color);
}
.woocommerce-MyAccount-navigation ul li a {
	display: block;
	padding: 1em 0;
	@include transition-color;
}
.woocommerce-MyAccount-navigation ul li:first-child a {
	padding-top: 0.5em;
}
.woocommerce-MyAccount-navigation li.is-active a {
	color: var(--theme-color-text_link);
}
.woocommerce-account .addresses .title h3 {
	font-size: 1.2em;
	line-height: 1.1em;
	margin-bottom: 0.7em;
}
.woocommerce table.my_account_orders {
	font-size: 1em;
}
.woocommerce table.shop_table tfoot td,
.woocommerce table.shop_table tfoot th {
	font-weight:400;
}
.woocommerce table.shop_table tfoot tr:last-child td {
	font-weight:700;
}
.woocommerce-account .woocommerce-MyAccount-content {
	width: 75%;
	float: right;
}
.woocommerce-MyAccount-content {
	.my_account_orders th {
		text-align: left;
	}
	.my_account_orders .button {
		padding: 0;
		background-color: transparent !important;
		color: var(--theme-color-text_link);
		@include box-shadow(none);
		@include border-radius(0);
		+.button:before {
			content: '|';
			display: inline-block;
			line-height: inherit;
			margin: 0 0.5em;
		}
	}
	.my_account_orders .button:hover,
	.my_account_orders .button:focus {
		color: var(--theme-color-text_hover);
	}
	.woocommerce-Address-title {
		position: relative;
		h3 {
			display: inline-block;
			margin-top: 0.5em;
		}
		a {
			margin: 0 0 0 5px;
			text-decoration: underline;
			font-size: 1em;
			line-height: 1.2em;
		}
	}
	.woocommerce-EditAccountForm fieldset {
		padding: 1em 1.5em;
		border: 1px solid var(--theme-color-bd_color);
		margin: 2em 0;
		legend {
			padding: 0 0.2em;
		}
	}
}
.woocommerce table.my_account_orders td, .woocommerce table.my_account_orders th {
	padding:10px 8px;
}
.woocommerce table.my_account_orders th {
	font-weight: 500;
	line-height: 1.5em;
	border: none !important;
	color: var(--theme-color-extra_dark) !important;
	background-color: var(--theme-color-extra_bg_color) !important;
}
.woocommerce form.checkout_coupon, .woocommerce form.login, .woocommerce form.register {
	@include border-sharp;
}

.woocommerce .woocommerce-MyAccount-content h3 {
	margin-top: 0;
}
.woocommerce .woocommerce-address-fields .select_container:before {
	top: 2px;
	right: 2px;
}
.woocommerce .woocommerce-address-fields .select2-container--default .select2-selection--single .select2-selection__arrow {
	display: none;
}


/* Responsive tables
----------------------------------------------------------------- */
.woocommerce table.shop_table_responsive tr td td:before,
.woocommerce-page table.shop_table_responsive tr td td:before {
	color: var(--theme-color-text_dark);
	font-weight: 700;
}
.woocommerce table.shop_table_responsive thead, .woocommerce-page table.shop_table_responsive thead {
	display:table-row-group;
}
.woocommerce table.shop_table_responsive tr, .woocommerce-page table.shop_table_responsive tr {
	display:table-row;
}
.woocommerce table.shop_table_responsive tr td, .woocommerce-page table.shop_table_responsive tr td {
	display:table-cell;
	text-align: left !important;
	vertical-align:top;
}
.woocommerce table.shop_table_responsive tr td.product-price, .woocommerce-page table.shop_table_responsive tr td.product-price,
.woocommerce table.shop_table_responsive tr td.product-quantity, .woocommerce-page table.shop_table_responsive tr td.product-quantity,
.woocommerce table.shop_table_responsive tr td.product-subtotal, .woocommerce-page table.shop_table_responsive tr td.product-subtotal {
	text-align: left !important;
}
.woocommerce table.shop_table_responsive tr td:before, .woocommerce-page table.shop_table_responsive tr td:before {
	display: none;
}


/* wishlist */
ul.products li.product .tinvwl_add_to_wishlist_button {
	margin-top: 1em;
}
.tinvwl_add_to_wishlist_button.tinvwl-add-hide {
	visibility: visible !important;
}


/* wishlist list */
.tinv-wishlist {
	.tinvwl-table-manage-list td.product-stock p {
		text-align: left;
		.tinvwl-txt {
			display: block;
		}
	}
	.tinv-header {
		display: none;
	}
	th {
		background-color: var(--theme-color-alter_bg_color) !important;
	}
	td {
		background-color: transparent !important;
	}
	table th,
	table td {
		padding: 30px;
		text-align: left;
		border: none !important;
		color: var(--theme-color-text_dark);
		font-size: 19px;
		line-height: 1.3em;
		font-weight: 700;
		.variation {
			font-weight: 400;
			font-size: 14px;
			color: var(--theme-color-text);
		}
		a {
			color: var(--theme-color-text_dark);
			&:hover {
				color: var(--theme-color-text_link);
			}
		}
		del,
		.amount,
		.amount * {
			color: var(--theme-color-text_dark) !important;
		}
	}
	tr + tr {
		border-top: 1px solid var(--theme-color-bd_color);
	}
	.product-thumbnail {
		min-width: 100px;
		width: 120px;
		padding-right: 0;
		padding-left: 0;
		img {
			@include border-radius(0);
			object-fit: cover;
			aspect-ratio: 1;
		}
	}
	.product-remove button {
		margin: 0;
		width: 27px;
		height: 27px;
		@include border-radius(0);
		padding: 0;
		border: 0;
		background-color: transparent !important;
		color: var(--theme-color-text_light);
		font-size: 14px;
		&:hover {
			color: var(--theme-color-text_link);
		}
		.ftinvwl:before {
			display: block;
			content: '\e9e1' !important;
			font-family: $theme_icons;
			line-height: 1;
			text-align: center;
			border: none;
			text-indent: 0;
			width: 100%;
			height: 100%;
		}
	}

	.product-stock i {
		display: none
	}
	.product-remove {
		padding-left: 10px;
	}

	.product-action {
		width: auto;
		text-align: right;
		.button {
			width: auto;
			i {
				font-weight: 400;
			}
		}
	}

	tfoot tr {
		border-top: 1px solid var(--theme-color-bd_color);
		.tinvwl-input-group {
			border-collapse: collapse;
		}
		td {
			padding: 70px 0 0 0;
		}
		button {
			padding-top: 0 !important;
			padding-bottom: 0 !important;
			height: 55px !important;
			line-height: 55px !important;
			.tinvwl-mobile {
				margin-left: 5px;
			}
		}
		.select_container {
			overflow: hidden;
		}
		.tinvwl-to-left:not(:empty) {
			min-height: 1px;
		}
	}

	td.product-name dl.variation dd {
		padding-top: 0.4em;
	}
	td.product-name dl.variation dt {
		padding-top: 0.4em;
		padding-right: 0.4em;
	}
	.social-buttons {
		margin-top: 60px;
		> span {
			margin-right: 15px;
		}
	}

	.tinv-lists-nav {
		margin: 10px -5px;
		> * {
			flex: unset;
			margin: 5px !important;
		}
		> span {
			@include font(0.9rem, 1rem, 500);
			color: var(--theme-color-text_dark);
		}
		.button {
			@include box(35px, 35px, 35px);
			@include box-shadow(none);
			float: none;
			padding: 0;
			i {
				margin: 0;
				text-indent: 2px;				
			}
			&.tinv-prev i {
				text-indent: -2px;
			}
			span {
				display: none;
			}
		}
	}
}
.tinvwl-input-group .form-control {
	height: 55px;
	padding: 0 25px;
	border: 1px solid var(--theme-color-input_bd_color);
	@include border-radius(0);
}
.tinvwl-input-group .select_container + .tinvwl-input-group-btn {
	padding-left: 10px;
}
.tinvwl-input-group .select_container:after {
	width: 3em;
}



/* Cart */
.sc_layouts_cart {
	z-index: 2001;
}
.sc_layouts_cart:not(.modern) .sc_layouts_cart_widget {
	text-align: left;
	position: absolute;
	z-index: 2;
	top: 65px;
	left: -2em;
	width: 330px;
	padding: 45px 30px;
	border: none;
	@include box-sizing(border-box);
	.sc_layouts_column_align_right & {
		right: -2em;
		left: auto;
	}
	&:after {
		display: none;
	}
	.woocommerce-mini-cart__empty-message {
		text-align: center;
		position: relative;
		font-size: 18px;
		line-height: 1.3em;
		padding: 3.8em 0;
		&:before {
			display: block;
			text-align: center;
			width: 100%;
			content: '\e9f4';
			font-family: $theme_icons;
			font-size: 28px;
			margin-bottom: 25px;
		}
	}
	a.remove {
		display: inline-block !important;
		top: 2px !important;
		font-size: 9px !important;
		right: 3px !important;
	}
	.widget_shopping_cart {
		position: relative;
		z-index: 2;
		ul.cart_list {
			padding-bottom: 10px;
			li {
				padding: 10px 13px 10px 0;
				img {
					margin-right: 17px;
				}
			}
		}
		.buttons {
			margin-top: 28px;
		}
		.buttons a {
			margin-right: 8px;
			width: calc(49.9% - 4px);
			font-size: 14px;
			line-height: 18px;
			padding: 11px;
			margin-bottom: 0 !important;
			&.checkout {
				padding: 9px;
			}
		}
	}
	.total {
		padding-top: 20px !important;
		margin-top: 0;
		border-top: 1px solid var(--theme-color-extra_bd_color) !important;
	}
	.sc_layouts_cart_widget_close {
		cursor: auto;
		width: 100%;
		height: 100%;
		position: fixed;
		left: 0;
		top: 0;
		z-index: 1;
		.sc_layouts_cart_widget_close_icon {
			display: none;
		}
	}
}

/* cart panel */
.sc_layouts_cart_panel {
	.sc_layouts_panel_close.trx_addons_button_close {
		top: 15px;
		right: 10px;
		@include box(30px, 30px, 30px);
		.trx_addons_button_close_icon {
			font-size: 11px;
		}
	}
	.sc_layouts_cart_panel_header {
		padding: 15px;
		background-color: transparent;
		border-bottom: 1px solid var(--theme-color-alter_bd_color);
		.sc_layouts_cart_panel_title {
			font-size: 1.3em;
			line-height: 1.3em;
		}
	}
	.sc_layouts_cart_panel_widget .widget_shopping_cart {
		.widget_shopping_cart_content {
			margin-right: 0;
			overflow-y: auto;
			overflow-x: hidden;
			/* Scrollbar decoration */
			// Firefox
			scrollbar-width: thin;
			// WebKit-based browsers
			&::-webkit-scrollbar {
				width: 6px;
			}
			&::-webkit-scrollbar-track {
				background: var(--theme-color-alter_bd_color);
			}
			&::-webkit-scrollbar-thumb {
				background-color: var(--theme-color-text_dark);
			}
			.total:after {
				content: "";
				display: block;
				background-color: var(--theme-color-alter_bg_color);
				@include abs-pos(0, 0, -1000%, 0, -1);
			}
		}
		ul.cart_list li {
			padding: 10px 15px 10px 0;
			margin-right: 5px;
			img {
				width: inherit;
			}
		}
	}
}

/* cart modern */
.sc_layouts_cart.modern .sc_layouts_cart_widget {
	text-align: left;
	position: fixed;
	z-index: 2;
	top: 0;
	bottom: 0;
	height: 100%;
	left: auto;
	right: 0;
	width: 490px;
	padding: 118px 50px 75px;
	border: none;
	opacity: 0.7 !important;
	display: block !important;
	@include transform(translateX(495px));
	-webkit-transition: all 0.4s ease-in-out !important;
	-ms-transition: all 0.4s ease-in-out !important;
	transition: all 0.4s ease-in-out !important;
	@include box-sizing(border-box);
	background-color: var(--theme-color-alter_bg_color) !important;
	color: var(--theme-color-alter_dark) !important;
	@include box-shadow(0 0 0 rgba(0,0,0, 0));

	ul.cart_list li a,
	.total,
	.total *,
	.quantity,
	.quantity * {
		color: var(--theme-color-alter_dark) !important;
	}
	.widget_shopping_cart_content .buttons a.checkout {
		border: none !important;
		color: var(--theme-color-inverse_hover) !important;
		background-color: var(--theme-color-alter_dark) !important;
		&:hover {
			color: var(--theme-color-inverse_link) !important;
			background-color: var(--theme-color-alter_link) !important;
		}
	}
	.sc_layouts_cart_widget .cart_list {
		max-height: 100%;
	}
	&:after {
		display: none;
	}
	.sc_layouts_item_text {
		font-size: 28px;
		margin: 0;
		position: absolute;
		left: 50px;
		top: 40px;
	}
	.sc_layouts_cart_widget_close {
		width: 2rem;
		height: 2rem;
		line-height: 2rem;
		text-align: center;
		font-size: 16px;
		right: 43px;
		top: 43px;
		color: var(--theme-color-alter_dark);
	}
	.woocommerce-mini-cart__empty-message {
		text-align: center;
		position: relative;
		font-size: 18px;
		line-height: 1.3em;
		padding: 0;
		margin: auto;
		&:before {
			display: block;
			text-align: center;
			width: 100%;
			content: '\e9f4';
			font-family: $theme_icons;
			font-size: 28px;
			margin-bottom: 25px;
		}
	}
	a.remove {
		display: block !important;
		top: 15px !important;
		font-size: 14px !important;
		margin: 0 !important;
		&:after {
			@include transition-all(0.3s);
		}
	}
	.widget_shopping_cart {
		position: relative;
		z-index: 2;
		padding: 0;
		height: 100%;
		font-size: 1em;
		border-top: 1px solid var(--theme-color-bd_color);
		.widget_shopping_cart_content {
			height: 100%;
			@include flex;
			flex-direction: column;
			justify-content: flex-end;
		}
		ul.cart_list {
			margin-bottom: auto;
			margin-top: 0;
			padding-top: 38px;
			max-height: 100%;
			overflow-y: auto;
			overflow-x: hidden;
		}
		ul.cart_list li {
			padding: 10px 20px 10px 0;
			img {
				margin-right: 22px;
			}
		}
		.buttons {
			margin-top: 33px;
		}
		.buttons a {
			border: none !important;
			margin-right: 20px;
			width: calc(50% - 10px);
			font-size: 15px;
			line-height: 55px;
			height: 55px !important;
			padding: 0 10px;
			margin-bottom: 0 !important;
			@include border-radius(0);
			@include box-shadow(none !important);
			&:not(.checkout) {
				color: var(--theme-color-alter_dark) !important;
				background-color: var(--theme-color-alter_bg_hover) !important;
				&:hover {
					color: var(--theme-color-inverse_link) !important;
					background-color: var(--theme-color-alter_link) !important;
				}
			}
		}
	}
	.total {
		padding-top: 33px !important;
		margin-top: 0;
		border-top: 1px solid #0F0F0F !important;
		@include flex;
		flex-direction: row;
		align-items: center;
		justify-content: space-between;
	}

}
.sc_layouts_cart.sc_layouts_cart_opened.modern .sc_layouts_cart_widget {
	@include transform(translateX(0px));
	opacity: 1 !important;
	@include box-shadow(0 3px 66px rgba(0,0,0, 0.05));
}


/* Wishlist */
body.woosq-open .tinv-wishlist .tinv-modal.tinv-modal-open {
	z-index: 999999 !important;
}
.tinv-wishlist .tinvwl_added_to_wishlist.tinv-modal button.button {
	margin-bottom: 0 !important;
	margin-top: 10px !important;
	text-align: center;
	display: inline-block;
	padding: 15px;
	.tinvwl_button_close i {
		display: none;
	}
}
.tinv-wishlist .tinv-modal .icon_big_heart_check,
.tinv-wishlist .tinv-modal .icon_big_times,
.tinv-wishlist .tinv-modal img {
	margin-bottom: 15px !important;
}
.tinv-wishlist .tinvwl_added_to_wishlist .tinv-txt {
	margin-bottom: 10px;
}
.tinv-wishlist .tinv-modal .tinvwl-buttons-group {
	margin-top: 10px;
	button > i {
		line-height: 0;
	}
}
.tinv-wishlist .tinv-modal .tinv-modal-inner {
	padding: 35px;
	background-color: var(--theme-color-bg_color);
}

.single_product_bottom_bar_product_button,
.woocommerce div.product form.cart {
	.tinv-wraper {
		float: left;		
		display: inline-block;
		pointer-events: all;
		font-size: 17px !important;
		.tinvwl_add_to_wishlist_button.tinvwl-add-hide {
			visibility: visible !important;
		}
		> * {
			display: none;
		}
		> .tinvwl_add_to_wishlist_button {
			display: block;
			overflow: hidden;
			color: #000000 !important;
			background-color: #ffffff !important;
			letter-spacing:0 !important;
			cursor:pointer;
			text-align:center;
			border: none !important;
			margin: 0 !important;
			@include box(55px, 55px, 56px !important);
			@include border-radius(50% !important);
			@include transition(all 0.2s ease !important);
			@include box-shadow(0 0 30px 0 rgba(0, 0, 0, 0.06));
			position: relative;
			visibility: visible !important;
			pointer-events: auto !important;
			top: 0;
			opacity: 1 !important;
			.tinvwl_add_to_wishlist-text {
				display: none;
			}
			&:before {
				display: block !important;
				content: '\e9cc' !important;
				font-family: $theme_icons !important;
				margin: 0 !important;
				font-size: 16px !important;
				line-height: inherit !important;
				vertical-align: middle !important;
				padding: 0 !important;
				height: 100% !important;
				width: 100% !important;
				text-align: center !important;
			}
			&.tinvwl-product-in-list:before {
				content: '\ea05' !important;
			}
			&:hover {
				color: var(--theme-color-text_link) !important;
			}
		}
	}
}

// Single cart button
.woocommerce div.product form.cart .single_add_to_cart_button {
	height: 55px;
	line-height: 1em !important;
	padding: 0 55px !important;
	margin-right: 10px;
	white-space: normal;
}

.pswp__caption .pswp__caption__center {
	text-align: center;
}

/* cart form */
.woocommerce .woocommerce-cart-form table.shop_table {
	th,
	td {
		padding: 30px 0;
		&:first-child {
			padding-left: 25px;
		}
	}
	.cart-coupon {
		border: none !important;
		padding-left: 0 !important;
	}
	td.product-name {
		width: 40%;		
		padding-right: 10px;
	}
	.product-name-inner {
		@include flex;
		align-items: center;
		.product-info {
			flex-grow: 1;
		}
		> a {
			flex: 0 0 auto;
		}
	}
	.product-name img {
		@include box(80px, 80px);
		object-fit: cover;
		aspect-ratio: 1;
		margin-right: 25px;
		@include border-radius(0);
	}

	.product-info > b { // product from Booking Calendar
		color: var(--theme-color-text_dark);
		font-weight: inherit;
	}

	tbody {
		font-size: 19px;
		line-height: 1.3em;
		font-weight: 700;
		color: var(--theme-color-text_dark);
		td {
			font-size: 19px;
			line-height: 1.3em;
		}
		a {
			color: var(--theme-color-text_dark);
			&:hover {
				color: var(--theme-color-text_link);
			}
		}
		span.amount,
		span.amount .woocommerce-Price-currencySymbol {
			color: var(--theme-color-text_dark);
		}
		.product-price span.amount {
			font-weight: 700;
		}
		a.remove {
			font-size: 18px !important;
		}
	}

	td.actions {
		text-align: right !important;
		padding-right: 0 !important;
		border: none !important;
	}
	td.actions,
	td.cart-coupon {
		padding-top: 78px;
		padding-bottom: 0;
	}

	.cart-coupon-inner {
		@include flex;
		position: relative;
		border: 1px solid var(--theme-color-bd_color);
		align-items: center;
		padding-left: 25px;
		height: 55px;
		@include box-sizing(border-box);
		@include border-radius(0);
		&:before {
			content: '\e9bd';
			font-family: $theme_icons;
			display: inline-block;
			color: var(--theme-color-text_dark);
			font-size: 22px;
			font-weight: 400;
		}
		input {
			padding: 13px 10px;
			font-size: 14px;
			font-weight: 400;
			line-height: normal;
			border: none;
			flex: 1 auto;
			width: 100%;
			margin-right: 155px;
		}
		button {
			display: inline-flex;
			width: 155px;
			padding: 0;
			position: absolute;
			top: 0;
			right: 0;
			bottom: 0;
			background: none;
			align-items: center;
			justify-content: center;
			font-size: 15px;
			@include border-radius(0);
			color: var(--theme-color-text_dark);
			background-color: var(--theme-color-bg_color);
			&:focus,
			&:hover {
				color: var(--theme-color-text_link);
			}
			&:before {
				content: "";
				display: block;
				height: 22px;
				width: 1px;
				@include abs-lc();
				left: 2px;
				background: var(--theme-color-bd_color);
			}
		}
	}

	.woo-actions-inner {
		.button {
			height: 55px;
			padding: 0 42px;
			font-size: 15px;
			line-height: 20px;
			font-weight: 700;
			&.continue_shopping {
				@include box-shadow(none);
				background-color: var(--theme-color-alter_bg_color);
				color: var(--theme-color-text_dark);
				&:hover {
					background-color: var(--theme-color-text_dark);
					color: var(--theme-color-inverse_hover);
				}
			}
		}
		button.button {
			background-color: var(--theme-color-text_dark);
			color: var(--theme-color-inverse_hover);
			@include box-shadow(none);
			&:focus,
			&:hover {
				background-color: var(--theme-color-text_link);
				color: var(--theme-color-inverse_link);
			}
		}
		.button + .button {
			margin-left: 13px;
		}
	}
}

.woocommerce #content table.cart img, .woocommerce table.cart img,
.woocommerce-page #content table.cart img, .woocommerce-page table.cart img {
	height: auto;
}

.woocommerce #content table.cart td.actions,
.woocommerce table.cart td.actions,
.woocommerce-page #content table.cart td.actions,
.woocommerce-page table.cart td.actions {
	text-align: right;
}



/* cart_totals */
.woocommerce .cart_totals .wc-proceed-to-checkout {
	padding: 1.9em 0 0;
	.checkout-button {
		margin: 0;
	}
}
.woocommerce .cart_totals table.shop_table {
	tr td,
	tr th {
		border: 1px solid var(--theme-color-bd_color) !important;
	}
	tr td {
		font-size: 17px;
	}
	tr th {
		background-color: var(--theme-color-alter_bg_color);
		color: var(--theme-color-alter_dark);
		font-size: 17px;
		font-weight: 700;
		line-height: 1.3em;
	}
}
.woocommerce .cart-collaterals .cart-subtotal .amount,
.woocommerce-page .cart-collaterals .cart-subtotal .amount {
	font-weight: 700 !important;
}
.woocommerce .cart-collaterals .order-total {
	span.amount {
		color: var(--theme-color-alter_dark);
	}
	strong {
		font-weight: 700;
	}
}
#add_payment_method .cart-collaterals .shipping-calculator-button:after,
.woocommerce-cart .cart-collaterals .shipping-calculator-button:after,
.woocommerce-checkout .cart-collaterals .shipping-calculator-button:after {
	display: none;
}
.woocommerce .cart-collaterals .cart_totals table {
	border-collapse:collapse;
}
.woocommerce .cart-collaterals .cart_totals table td,
.woocommerce-page .cart-collaterals .cart_totals table td {
	padding: 24px 28px;
	vertical-align:middle;
}
.woocommerce .cart-collaterals .cart_totals table th,
.woocommerce-page .cart-collaterals .cart_totals table th {
	padding: 24px;
	font-weight: 500;
	text-align:left;
	vertical-align:middle;
}
.woocommerce .cart-collaterals .cart_totals table select,
.woocommerce-page .cart-collaterals .cart_totals table select {
	font-size:1em;
	color: var(--theme-color-input_text);
	background-color: var(--theme-color-input_bg_color);
}
.woocommerce .cart-collaterals .cart_totals table select:focus,
.woocommerce-page .cart-collaterals .cart_totals table select:focus {
	color: var(--theme-color-input_dark);
	background-color: var(--theme-color-input_bg_hover);
}
.woocommerce .cart-collaterals .shipping_calculator .shipping-calculator-button:after,
.woocommerce-page .cart-collaterals .shipping_calculator .shipping-calculator-button:after {
	color: var(--theme-color-text_dark);
}


/* Status Bar */
.woocommerce-checkout .woocommerce_status_bar {
	margin-top: 100px;
}
.woocommerce-checkout .woocommerce-order .woocommerce_status_bar {
	margin-top: 0;
}
.woocommerce_status_bar {
	font-size: 17px;
	font-weight: 700;
	line-height: 1.3em;
	color: var(--theme-color-text_dark);
	@include flex;
	flex-direction: row;
	justify-content: center;
	padding: 0;
	margin-bottom: 100px;
	> div {
		padding: 0 70px;
		position: relative;
		&.bar_cart:after,
		&.bar_payment:after {
			content: '\e9df';
			font-family: $theme_icons;
			display: inline-block;
			color: var(--theme-color-text_dark_02);
			font-weight: 400;
			font-size: 11px;
			@include abs-rc();
			width: 20px;
			text-align: center;
			right: -10px;
		}
	}
	.num {
		width: 34px;
		height: 34px;
		line-height: 31px;
		font-size: 16px;
		text-align: center;
		display: inline-block;
		@include border-radius(0);
		background-color: var(--theme-color-text_dark);
		color: var(--theme-color-bg_color);
		margin-right: 16px;
	}
	.active .num {
		background-color: var(--theme-color-text_link);
		color: var(--theme-color-inverse_link);
	}
}
.woocommerce-checkout .woocommerce-order .woocommerce_status_bar .num {
	background-color: var(--theme-color-text_link);
	color: var(--theme-color-inverse_link);
}

.woocommerce form .form-row.woocommerce-invalid label {
	color: #FF5B4A !important;
	.required {
		color: #FF5B4A !important;
	}
}
.woocommerce form .form-row.woocommerce-invalid .select2-container,
.woocommerce form .form-row.woocommerce-invalid input.input-text,
.woocommerce form .form-row.woocommerce-invalid .select2-selection,
.woocommerce form .form-row.woocommerce-invalid .select2-selection__rendered,
.woocommerce form .form-row.woocommerce-invalid select {
	border-color: #FF5B4A !important;
}
.woocommerce form .form-row .required {
	color: #FF5B4A !important;
}

/* checkout */
.woocommerce form .form-row-first,
.woocommerce form .form-row-last,
.woocommerce-page form .form-row-first,
.woocommerce-page form .form-row-last {
	width: calc(50% - 15px);
}
h3#ship-to-different-address label > span {
	font-size: 19px;
	line-height: 1em;
	font-weight: 500;
	padding-left: 28px;
}
form.woocommerce-checkout {
	overflow: hidden;
	> h3#order_review_heading {
		overflow: hidden;
		margin: 0;
		padding-bottom: 34px;
		font-size: 35px;
		line-height: 1.2em;
	}

	label {
		font-size: 19px;
		line-height: 1.1em !important;
		font-weight: 500;
		margin-bottom: 15px;
		color: var(--theme-color-text_dark);
		.required {
			color: var(--theme-color-text_dark) !important;
		}
	}

	h3.ship-to-different-address {
		margin: 0;
		line-height: 1.2em;
	}

	#customer_details {
		width: 60%;
		float: left;
		overflow: hidden;
		padding-right: 140px;
		@include box-sizing(border-box);
		.col-1,
		.col-2 {
			width: 100%;
			float: none;
		}
		.woocommerce-billing-fields h3 {
			font-size: 47px;
			line-height: 1.1em;
		}
	}
	#order_review {
		width: 40%;
		float: right;
		#order_review_heading {
			padding-top: 0;
			margin-top: 0;
			overflow: hidden;
		}
	}

}

.shop_table_checkout_review {
	padding: 18px 50px;
	color: var(--theme-color-alter_dark);
	background-color: var(--theme-color-alter_bg_color);
	table {
		width: 100%;
		margin: 0;
		th,
		td {
			font-size: 17px;
			line-height: 1.3em;
			font-weight: 700;
			background: transparent !important;
			padding: 25px 0;
			color: var(--theme-color-alter_dark);
			text-align: right;
			strong {
				font-weight: 700;
			}
			span.amount,
			* {
				color: var(--theme-color-alter_dark);
			}
		}
		td:last-child {
			padding-left: 8px;
		}
		tr {
			> th:first-child,
			> td:first-child {
				text-align: left;
			}
			+ tr {
				border-top: 1px solid var(--theme-color-alter_bd_color);
			}
			&.order-total {
				*,
				span.amount {
					color: var(--theme-color-alter_link);
				}
			}
			ul#shipping_method li label {
				font-size: 17px;
				line-height: 1.3em;
				font-weight: 700;
			}
		}

	}
}



.shop_table_order_details {
	padding: 18px 50px;
	color: var(--theme-color-alter_dark);
	background-color: var(--theme-color-alter_bg_color);
	table.shop_table {
		width: 100%;
		margin: 0;
		.wc-item-meta {
			margin-top: 5px;
			li {
				font-size: 0.9em;
				line-height: 1.5em;
			}
		}
		th,
		td {
			font-size: 17px;
			line-height: 1.3em;
			font-weight: 500;
			background: transparent !important;
			padding: 25px 0;
			color: var(--theme-color-alter_dark);
			text-align: right;
			strong {
				font-weight: 500;
			}
			span.amount,
			* {
				color: var(--theme-color-alter_dark);
			}
		}
		tr {
			> th:first-child,
			> td:first-child {
				text-align: left;
			}
			+ tr {
				border-top: 1px solid var(--theme-color-alter_bd_color);
			}
			&.order-total {
				*,
				span.amount {
					color: var(--theme-color-alter_link);
				}
			}
			&:last-child {
				td {
					border-bottom: none !important;
				}
			}
		}

	}
}
.woocommerce .woocommerce-order-details {
	margin-bottom: 60px;
	.order-again {
		margin-top: var(--theme-var-grid_gap);
	}
}
.woocommerce-customer-details .woocommerce-column__title,
.woocommerce-order-details .woocommerce-order-details__title {
	margin: 0;
	padding-bottom: 30px;
	font-size: 35px;
	line-height: 1.2em;
}
.woocommerce .woocommerce-customer-details address {
	border-width: 1px !important;
	border-color: var(--theme-color-alter_bd_color);
	padding: 30px;
	@include border-radius(0);
}



/* Payment */
#add_payment_method #payment ul.payment_methods, .woocommerce-cart #payment ul.payment_methods, .woocommerce-checkout #payment ul.payment_methods {
	padding: 18px 50px;
	border: none;
}
#add_payment_method #payment ul.payment_methods li, .woocommerce-cart #payment ul.payment_methods li, .woocommerce-checkout #payment ul.payment_methods li {
	line-height: 1;
}
#add_payment_method #payment div.form-row, .woocommerce-cart #payment div.form-row, .woocommerce-checkout #payment div.form-row {
	padding: 5px 50px 50px;
	font-size: 14px;
	font-weight: 400;
	line-height: 1.6em;
	color: var(--theme-color-alter_text);
	text-align: left;
}
.woocommerce #payment #place_order,
.woocommerce-page #payment #place_order {
	float: left;
}
.woocommerce form .form-row label.checkbox,
.woocommerce-page form .form-row label.checkbox {
	display: inline-block;
	padding-left: 1.8em;
}
#payment {
	margin: 48px 0 0 0;
	.place-order,
	.wc_payment_methods {
		color: var(--theme-color-alter_dark);
		background-color: var(--theme-color-alter_bg_color);
		border: none;
	}
	.place-order {
		.woocommerce-terms-and-conditions-wrapper p {
			margin: 0 0 27px;
			.woocommerce-privacy-policy-link {
				color: var(--theme-color-alter_link);
				border-bottom: 1px solid var(--theme-color-alter_link);
				display: inline-block;
				line-height: 1em;
			}
		}
	}
	#order_review_heading_payment {
		margin: 0;
		padding-bottom: 35px;
		font-size: 35px;
		line-height: 1.2em;
	}

	ul.methods {
		div.payment_box {
			padding: 0;
			margin: 4px 0 0 0;
			font-size: 15px;
			line-height: 1.7em;
			color: var(--theme-color-alter_text);
			background-color: transparent;
			font-weight: 400;
		}
		label {
			font-size: 17px;
			line-height: 1.3em !important;
			font-weight: 700;
			margin-bottom: 0;
		}
		li {
			padding: 23px 0;
			font-weight: 400;
			&:last-child {
				border-bottom: 1px dashed var(--theme-color-alter_bd_color);
			}
		}
		li + li {
			border-top: 1px solid var(--theme-color-alter_bd_color);
		}

	}
}
body.woocommerce-checkout #payment h3 + div.place-order {
	padding: 0;
	background-color: transparent;
	.button {
		@include box-shadow(none);
	}
}

/* Stripe */
.woocommerce-checkout #payment .payment_method_stripe {
	div.form-row {
		padding: 0;
	}
	.wc-credit-card-form {
		.wc-stripe-elements-field,
		.wc-stripe-iban-element-field {
			padding: 0.6em 0;
			margin: 0;
			border: none;
			border-bottom-width: 1px;
			border-bottom-style: solid;
			border-color: var(--theme-color-input_bd_color);
			background-color:  var(--theme-color-input_bg_color);
		}
		.wc-stripe-elements-field iframe {
				min-height: auto;
			}
		label {
			@include font(14px, 20px, 600);
			padding-left: 0;
		}
		.stripe-source-errors ul li {
			@include font(15px, 21px);
			padding: 0;
			text-align: center;
			&:last-child {
				border-bottom: none;
			}
		}
		+ fieldset {
			padding: 0;
		}
	}
	#wc-stripe-new-payment-method {
		display: none;
		+ label {
			display: inline-block !important;
			@include font(14px, 1.5em !important, inherit);
			color: var(--theme-color-text);
			&:before {
				top: 0.5em;
			}
		}
	}
}


/* Attributes */
.woocommerce table.shop_attributes th {
	padding: 10px;
	background: none !important;
}
.woocommerce table.shop_attributes td {
	font-style: normal;
	background: none !important;
}



/* Extended slider */
.sc_extended_products .woocommerce .sc_extended_products_slider {
	ul.products li.product {
		padding-bottom: 0 !important;
	}
}
.sc_extended_products .slider_outer_centered .slider-slide {
	@include transition(all 0.35s ease-in-out);
	&:not([class*="next"]):not([class*="active"]):not([class*="prev"]) {
		opacity: 0.35;
	}
}


/* Extended Default */
.sc_extended_products_default {
	.woocommerce ul.products li.product {
		padding-bottom: 55px;
	}
	.woocommerce.columns-5 ul.products li.product,
	.woocommerce.columns-6 ul.products li.product,
	.woocommerce.columns-7 ul.products li.product,
	.woocommerce.columns-8 ul.products li.product {
		padding-bottom: 45px;
	}
}

/* Extended Centered */
.woocommerce ul.products.products_style_centered li.product {
	padding-bottom: 55px;
	.star-rating {
		margin-left: auto;
		margin-right: auto;
	}
	.post_data {
		text-align: center;
	}
}


/* Extended Simple */
.woocommerce ul.products.products_style_simple li.product {
	padding-bottom: 30px;
	> .post_item.post_layout_thumbs {
		height: auto;
	}
	.post_featured {
		margin-bottom: 0 !important;
	}
	.post_data {
		padding: 26px 15px;

		.price {
			opacity: 1;
			@include transition-all(0.3s);
		}

		.add_to_cart_wrap {
			margin: 0 0 -20px;
			height: 27px;
		}

		.post_header + .add_to_cart_wrap {
			margin: 29px 0 -22px 0;
		}

		.add_to_cart_wrap .added_to_cart,
		.add_to_cart_wrap .button {
			display: inline-block !important;
			@include box-shadow(none);
			padding: 0 0 7px 0;
			@include border-radius(0);
			background: none !important;
			color: var(--theme-color-text_dark);
			line-height: 20px;
			font-size: 16px;
			font-weight: 700;
			margin: 0;
			opacity: 0;
			position: relative;
			&.added {
				display: none !important;
			}			
			&:after {
				position: absolute;
				bottom: 0;
				top: auto;
				left: 0;
				content: "";
				display: block;
				width: 100%;
				height: 2px;
				background-color: var(--theme-color-text_dark);
				@include transition-all(0.3s);
				animation: none;
				font-weight: 400;
			}
			&:hover {
				color: var(--theme-color-text_dark);
				&:after {
					bottom: 4px;
					background-color: var(--theme-color-text_dark);
				}
			}
		}

		p.price,
		span.price,
		span.amount {
			color: var(--theme-color-text_dark);
		}
	}

	.post_item {
		@include box-shadow(0 0 0 rgba(0,0,0,0));
		@include transition-all(0.3s);

		&:hover {
			@include box-shadow(0 3px 26px rgba(0,0,0, .04));

			.woocommerce-loop-product__title a {
				color: var(--theme-color-text_light);
			}
			.price {
				opacity: 0;
			}
			.add_to_cart_wrap .button,
			.add_to_cart_wrap .added_to_cart {
				margin-top: -22px;
				opacity: 1;
			}
			.add_to_cart_wrap .button.loading {
				opacity: 0.5 !important;
			}
		}
		.woocommerce-loop-product__title a:hover {
			color: var(--theme-color-text_dark);
		}
	}

	.star-rating {
		margin-left: auto;
		margin-right: auto;
		display: none;
	}
	.post_data {
		text-align: center;
	}
}

/* Extended Hovered */
.woocommerce ul.products.products_style_hovered li.product {
	padding-bottom: 30px;
	.post_featured {
		margin: 0;
	}
	.post_data {
		display: none;
	}
	.price {
		margin: 9px 0 0 0;
	}
	
	// hover
	.onsale,
	.outofstock_label {
		display: none !important;
	}
	.post_featured.hover_shop .icons {
		@include abs-cc();
		width: 100%;
		.item-hovered-info {
			display: block;
			width: 100%;
			text-align: center;
			opacity: 0;
			padding: 0 10px;
			margin: 0 0 7px;
			@include box-sizing(border-box);
			@include transition-all(0.3s);
		}
		.tinvwl_add_to_wishlist_button,
		> a .icon-anim {
			@include box-shadow(0 3px 36px rgba(0,0,0, 0.11));
		}
	}
	.post_featured.hover_shop:hover {
		.item-hovered-info {
			opacity: 1;
		}
	}
	.price del:before {
		background-color: #0C0F26 !important;
	}
	.woocommerce-loop-product__title a,
	.price del,
	.price span.amount,
	.price del > span.amount *,
	.price del > span.amount,
	.price * {
		color: #0C0F26 !important;

	}
	.price del {
		opacity: 0.5 !important;
	}
	.post_featured.hover_shop .mask {
		display: block;
		background-color: #ffffff !important;
		opacity: 0;
		z-index: 1;
	}
	.post_featured.hover_shop:hover .mask {
		opacity: 0.9;
	}
}

/* Extended Info */
.woocommerce ul.products.products_style_info li.product {
	padding-bottom: 55px;
	.post_featured {
		margin-bottom: 22px;
	}
	.woocommerce-loop-category__title,
	.woocommerce-loop-product__title,
	h3 {
		font-size: 19px;
		line-height: 1.3em;
	}
	.post_featured.hover_shop .icons {
		flex-direction: column;
		align-items: flex-end;
		justify-content: flex-start;
		top: 22px;
		right: 17px;
		> a .icon-anim,
		.tinv-wraper > .tinvwl_add_to_wishlist_button {
			margin: 3px !important;
		}
		.tinv-wraper > .tinvwl_add_to_wishlist_button:hover,
		> a:hover .icon-anim {
			top: 0 !important;
		}
	}
}
.woocommerce ul.columns-5.products.products_style_info li.product,
.woocommerce ul.columns-6.products.products_style_info li.product,
.woocommerce ul.columns-7.products.products_style_info li.product,
.woocommerce ul.columns-8.products.products_style_info li.product {
	padding-bottom: 45px;
}


/* Extended Info 2 */
.woocommerce ul.products.products_style_info_2 li.product {
	padding-bottom: 55px;
	.post_featured {
		margin-bottom: 22px;
	}
	.woocommerce-loop-category__title,
	.woocommerce-loop-product__title,
	h3 {
		font-size: 19px;
		line-height: 1.3em;
		font-weight: 700;
	}
	.price {
		margin: 14px 0 0 0;
	}
	.star-rating {
		margin: 8px 0 0;
	}
}
.woocommerce ul.columns-5.products.products_style_info_2 li.product,
.woocommerce ul.columns-6.products.products_style_info_2 li.product,
.woocommerce ul.columns-7.products.products_style_info_2 li.product,
.woocommerce ul.columns-8.products.products_style_info_2 li.product {
	padding-bottom: 40px;
}



/* pswp */
.pswp__button--arrow--left:before,
.pswp__button--arrow--right:before {
	top: 30px;
	background: none !important;
	height: 30px;
	width: 30px;
	line-height: 30px;
	font-family:$theme_icons;
	color: var(--theme-color-text_link);
	font-size: 14px;
}
.pswp__button--arrow--right:before {
	content: '\e9df';
	right: 10px;
}
.pswp__button--arrow--left:before {
	left: 10px;
	content: '\ea07';
}



/* Widget Woocommerce Title */
.widget_woocommerce_title {
	.woocommerce-breadcrumb {
		margin-bottom: 0.5em;
	}
	.term-description {
		margin-top: 1em;
	}
}


/* checkout in place order */
.woocommerce-checkout-payment .place-order label.checkbox {
	font-size: 14px !important;
	line-height: 18px !important;
	margin-bottom: 0;
	vertical-align: top;
	padding-top: 1px;
	.woocommerce-terms-and-conditions-checkbox-text {
		font-size: 14px;
		line-height: 22px;
		font-weight: 400;
		color: var(--theme-color-text);
	}
}



// Wishlist icon for Plain/Creative/Pure Styles
@mixin wishlist_icon() {
	.tinv-wraper {
		> * {
			display: none;
		}
		> .tinvwl_add_to_wishlist_button {
			display: block;
			overflow: hidden;
			color: var(--theme-color-alter_dark);
			background-color: var(--theme-color-alter_bg_color);
			letter-spacing: 0 !important;
			margin: 0 !important;
			@include border-radius(50% !important);
			@include box(35px, 35px, 37px !important);
			@include transition(all 0.2s ease !important);
			visibility: visible !important;
			pointer-events: auto;
			&:before {
				display: block !important;
				content: '\e9cc' !important;
				font-family: $theme_icons !important;
				margin: 0 !important;
				font-size: 15px !important;
				line-height: inherit !important;
				padding: 0 !important;
				height: 100% !important;
				width: 100% !important;
				text-align: center !important;
			}
			&.tinvwl-product-in-list:before {
				content: '\ea05' !important;
			}
			&:hover {
				color: var(--theme-color-alter_text);
			}
			.tinvwl_add_to_wishlist-text {
				display: none;
			}
		}
	}
}


/* --- Product Style Plain --- */
@media #{$media_lg_over} {
	.woocommerce ul.products .product_style_plain {
		&:not(.product-category) .post_item:hover {
			z-index: 2;
			&:before,
			.wrap-data-hover {
				opacity: 1;
				visibility: visible;
				@include transition-all(0.25s);
			}
			.wrap-data-hover {
				margin-top: 0;
			}
		}		
		.post_item,
		.post_data,
		.post_featured {
			position: relative;
			z-index: 1;
		}
		.post_item:before,
		.wrap-data-hover {
			margin-left: -15px;
			margin-right: -15px;
			background-color: var(--theme-color-bg_color);
			border: 1px solid var(--theme-color-bd_color);			
			opacity: 0;
			visibility: hidden;
		}
		.post_item:before {
			display: block;
			content: "";
			width: auto;
			height: auto;
			@include abs-pos(0,-1px,-1px,-1px);
			margin-top: -15px;
		}
		.wrap-data-hover {
			margin-top: -5px;
			padding: 0 15px 15px;
			position: absolute;
			z-index: -1;
			right: -1px;
			left: -1px;
			border-top: none;
		}
	}
}

.woocommerce ul.products.product_style_plain li.product {
	padding-bottom: 50px;
}

.product_style_plain {
	.woocommerce ul.products &.product {
		.post_item.post_layout_thumbs {
			height: unset;
		}
		.post_data {
			overflow: visible;
		}
		.wrap-data-info {
			margin-top: 8px;
			display: flex;
			flex-direction: row;
			align-items: center;
			justify-content: space-between;
			.star-rating {
				margin: -1px 0 -3px;
				flex-shrink: 0;
			}
			.price {
				margin: 0;
			}
		}
		.post_featured {
			margin-bottom: 20px;
		}
		.post_featured img,
		.post_featured:hover img,
		a img,
		a:hover img {
			@include scale(1, 1);
		}
		.outofstock_label,
		.onsale {
			top: 20px;
			left: 20px;
			padding: 0 15px;
			min-width: 50px;
		}
		.outofstock_label {
			top: 20px;
			left: 20px;
			+ .onsale {
				top: 51px;
				left: 20px;
				right: auto;
			}
	 	}
		.wrap-data-hover .add_to_cart_wrap {
			margin: 25px 0 0 0;
			[class*="cart"] {
				display: flex !important;
				flex-direction: row;
				align-items: center;
				justify-content: center;
				height: 100%;
				width: 100%;
				pointer-events: auto;
				white-space: normal;
				padding: 10px;
				height: 50px;
				margin: 0;
				@include font(14px, 16px);
				color: var(--theme-color-bg_color);
				@include box-shadow(none);
				background-color: var(--theme-color-text_dark);
				@include border-radius(0);
				@include border-box();
				&:before {
					margin: 0 5px 0 0;
					font-size: 16px;
					font-weight: 400;
					min-width: 20px;
					text-align: center;
				}
				&.loading:before {
					font-size: 14px !important;
					content: '\e82e';
					position: relative;
					top: 1px;
					@include animation(spin 2s infinite linear);
				}
				&.added_to_cart:before {
					font-family: $theme_icons;
					content: '\e8ab';
				}
				&.added {
					display: none !important;
				}
				&:hover {
					color: var(--theme-color-inverse_hover);
					background-color: var(--theme-color-text_dark_blend);
				}
			}
		}
	}	
	.post_featured .top-info {
		pointer-events: none;
		@include abs-pos(20px, 20px, auto, auto, 10);
		@include wishlist_icon();
	}
}

@mixin mini_plain ($start: 1, $end: 1, $class: '') {
	$var: '';
	$sep: ',';
	@for $i from $start through $end {
		@if $end == $i {
			$sep: '';
		}
		$var: $var + "ul.products.products_style_plain.columns-#{$i} li.product" + $sep;
	}

	@if($class != '' or ($start == 0 or $end == 0)) {
		$var: "ul.products.products_style_plain#{$class} li.product";
	}

	#{$var} {
		.outofstock_label,
		.onsale {
			top: 15px;
			left: 15px;
			padding: 0 10px;
			min-width: 30px;
		}
		.outofstock_label {
			top: 15px;
			left: 15px;
			+ .onsale {
				top: 46px;
				left: 15px;
				right: auto;
			}
		}
		.top-info {
			top: 15px;
			right: 15px;
		}
		.wrap-data-info {
			flex-direction: column;
			align-items: start;
			.star-rating {
				margin: 10px 0 0;
			}
		}
		.wrap-data-hover .add_to_cart_wrap {
			margin-top: 17px;
			[class*="cart"] {
				height: 42px;
			}
		}
	}
}

@media #{$media_lg_over} {
	body.body_style_ {
		&fullwide,
		&fullscreen {
			@include mini_plain(6,8);
			&.sidebar_show {
				@include mini_plain(5,8);
			}
		}
		&wide,
		&boxed {
			@include mini_plain(5,8);
			&.sidebar_show {
				@include mini_plain(4,8);
			}
		}
	}
}
@media #{$media_lg} {
	body[class*="body_style_"] {
		@include mini_plain(0,0, ':not(.columns-1):not(.columns-2):not(.columns-3)');
		&.sidebar_show {
			@include mini_plain(0,0, ':not(.columns-1):not(.columns-2)');
		}
	}
}
@media #{$media_md} {
	body[class*="body_style_"] {
		@include mini_plain(0,0);
	}
}


/* --- Product Style Creative --- */
.woocommerce ul.products.products_style_creative li.product {
	padding-bottom: 50px;
}
.product_style_creative {

	.woocommerce ul.products &.product {
		.post_featured {
			margin-bottom: 18px;
		}
		.post_item.post_layout_thumbs {
			height: unset;
		}
		.post_data {
			overflow: visible;
		}		
		.wrap-data-info {
			margin-top: 10px;
			display: flex;
			flex-direction: row;
			align-items: center;
			justify-content: space-between;
			.star-rating {
				margin: 0 0 -3px;
				flex-shrink: 0;
			}
			.price {
				margin: 0;
			}
		}
		.post_featured img,
		.post_featured:hover img,
		a img,
		a:hover img {
			@include scale(1, 1);
		}
		.outofstock_label,
		.onsale {
			top: 23px;
			left: 23px;
			padding: 0 15px;
			min-width: 50px;
		}
		.outofstock_label {
			top: 23px;
			left: 23px;
			+ .onsale {
				top: 54px;
				left: 23px;
				right: auto;
			}
	 	}
	}
	
	.post_featured.hover_shop {
		.mask {
			display: block;
			opacity: 0;
			background-color: rgba(0, 0, 0, 0.1);
			@include transition-all(0.3s);
		}
		.top-info {
			pointer-events: none;
			@include abs-pos(23px, 23px, auto, auto, 10);
			@include wishlist_icon();
		}
		.bottom-info {
			opacity: 0;
			@include transition-all(0.2s);
			@include abs-pos(auto, 0, 0, 0, 10);
			pointer-events: none;
			@include flex;
			flex-direction: row;
			align-items: center;
			background-color: var(--theme-color-alter_bg_color);
			height: 52px;
			> div {
				width: 50%;
				padding: 5px;
				display: flex;
				flex-direction: column;
				align-items: center;
				justify-content: center;
				height: 100%;
				position: relative;
				bottom: -4px;
				@include transition-all(0.2s);
				&:only-child {
					width: 100%;
				}
			}
			.add_to_cart_wrap {
				[class*="cart"] {
					display: flex;
					flex-direction: row;
					justify-content: center;
					align-items: center;
					height: 100%;
					width: 100%;
					pointer-events: auto;
					white-space: normal;
					@include box-shadow(none);
					@include border-radius(0);
					padding: 0;
					margin: 0;
					background: none !important;
					color: var(--theme-color-alter_dark);
					line-height: 16px;
					font-size: 14px;
					font-weight: 700;
					&:before {
						margin: 0 5px 0 0;
						font-size: 16px;
						font-weight: 400;
						min-width: 20px;
						text-align: center;
					}
					&.loading:before {
						font-size: 14px !important;
						content: '\e82e';
						position: relative;
						top: 1px;
						@include animation(spin 2s infinite linear);
					}
					&.added_to_cart:before {
						font-family: $theme_icons;
						content: '\e8ab';
					}
					&.added {
						display: none !important;
					}
					&:hover {
						color: var(--theme-color-alter_text);
					}
				}
			}
			.woosq_wrap {
				@include transition-all(0.2s);
				.woosq-btn {
					display: flex;
					flex-direction: row;
					justify-content: center;
					align-items: center;
					height: 100%;
					width: 100%;
					pointer-events: auto;
					white-space: normal;
					@include box-shadow(none);
					@include border-radius(0);
					padding: 0;
					margin: 0;
					background: none !important;
					color: var(--theme-color-alter_dark);
					line-height: 16px;
					font-size: 14px;
					font-weight: 700;
					&:before {
						font-family: $theme_icons !important;
						content: '\e843';
						margin: 0 8px 0 0;
						font-size: 16px;
						font-weight: 400;
						position: relative;
						top: 0;
					}
					&:hover {
						color: var(--theme-color-alter_text);
					}
				}
			}
		}		
	}
	
	.post_item {		
		&:hover .post_featured.hover_shop {
			.mask {
				opacity: 1;
			}
			.bottom-info {
				opacity: 1;
				> div {
					bottom: 0;
				}
			}
		}
	}
}

@mixin mini_creative ($start: 1, $end: 1, $class: '') {
	$var: '';
	$sep: ',';
	@for $i from $start through $end {
		@if $end == $i {
			$sep: '';
		}
		$var: $var + "ul.products.products_style_creative.columns-#{$i} li.product.product_style_creative" + $sep;
	}

	@if($class != '' or ($start == 0 or $end == 0)) {
		$var: "ul.products.products_style_creative#{$class} li.product.product_style_creative";
	}

	#{$var} {
		.outofstock_label,
		.onsale {
			top: 15px;
			left: 15px;
			padding: 0 10px;
			min-width: 30px;
		}
		.outofstock_label {
			top: 15px;
			left: 15px;
			+ .onsale {
				top: 46px;
				left: 15px;
				right: auto;
			}
		}
		.top-info {
			top: 15px;
			right: 15px;
		}		
		.wrap-data-info {
			flex-direction: column;
			align-items: start;
			.star-rating {
				margin: 10px 0 0;
			}
		}
		.bottom-info {
			height: 40px;
			> div > a {
				text-indent: -1000px;
				overflow: hidden;
				font-size: 0 !important;
				&:before {
					text-indent: 0;
					margin: 0;
					font-size: 18px;
				}
			}
		}
	}
}

@media #{$media_lg_over} {
	// for Shop page
	body.body_style_ {
		&fullwide,
		&fullscreen {
			@include mini_creative(6,8);
			&.sidebar_show {
				@include mini_creative(5,8);
			}
		}
		&wide,
		&boxed {
			@include mini_creative(5,8);
			&.sidebar_show {
				@include mini_creative(4,8);
			}
		}
	}
}
@media #{$media_xxl} {
	body[class*="body_style_"] {
		@include mini_creative(5,8);
		&.sidebar_show {
			@include mini_creative(4,8);
		}
	}
}
@media #{$media_xl} {
	body[class*="body_style_"] {
		@include mini_creative(0,0, ':not(.columns-1):not(.columns-2):not(.columns-3)');		
	}
}
@media #{$media_lg} {
	body[class*="body_style_"] {
		&.sidebar_show {
			@include mini_creative(0,0, ':not(.columns-1):not(.columns-2)');
		}
	}
}
@media #{$media_md} {
	body[class*="body_style_"] {
		@include mini_creative(0,0, ':not(.columns-1):not(.columns-2)');
	}
}
@media #{$media_sm} {
	body[class*="body_style_"] {
		@include mini_creative(0,0);
	}
}


/* --- Product Style Pure --- */
.product_style_pure {

	.woosq-btn {
		display: none;
	}
	.woocommerce ul.products &.product {
		.post_featured {
			margin-bottom: 18px;
		}
		.post_item.post_layout_thumbs {
			height: unset;
			padding-bottom: 10px;
			margin-bottom: -10px;
			overflow: hidden;
		}
		.post_data {
			overflow: visible;
		}
		.price {
			opacity: 1;
			position: relative;
			top: 0;
			@include transition-all(0.3s);
			.price {
				margin: 10px 0 0;
			}
		}
		.post_featured img,
		.post_featured:hover img,
		a img,
		a:hover img {
			@include scale(1, 1);
		}
		.outofstock_label,
		.onsale {
			top: 23px;
			left: 23px;
			padding: 0 15px;
			min-width: 50px;
		}
		.outofstock_label {
			top: 23px;
			left: 23px;
			+ .onsale {
				top: 54px;
				left: 23px;
				right: auto;
			}
	 	}
		.post_data_inner {
			position: relative;
			z-index: 1;
		}
		.wrap-data-hover {
			position: absolute;
			bottom: -10px;
			z-index: 1;
			width: 100%;
			opacity: 0;
			@include transition-all(0.3s);
			.add_to_cart_wrap {	
				margin: 0;
				display: block;
				line-height: 0;				
				[class*="cart"] {
					display: inline-block !important;			
					width: auto;
					white-space: normal;
					@include box-shadow(none);
					@include border-radius(0);
					padding: 0;
					margin: 0;
					background: none !important;
					color: var(--theme-color-text);
					line-height: 17px;
					font-size: 15px;
					font-weight: 700;
					&:before {
						margin: 0 5px 0 0;
						font-size: 16px;
						font-weight: 400;
						min-width: 20px;
						text-align: center;
					}
					&.loading:before {
						content: '\e82e';
						@include animation(spin 2s infinite linear);
					}
					&.added_to_cart:before {
						font-family: $theme_icons;
						content: '\e8ab';
					}
					&.added {
						display: none !important;
					}
					&:hover {
						color: var(--theme-color-text_dark);
					}
				}
			}
		}

		.post_header + .wrap-data-hover {
			margin-top: 10px;
			position: relative;
		}

		.post_item:hover {
			.wrap-data-hover {
				opacity: 1;
				bottom: 0;
			}
			.price {
				opacity: 0;
				top: -10px;
			}
			.post_featured.hover_shop {
				.mask {
					opacity: 1;
				}
				.bottom-info {
					opacity: 1;
					.woosq_wrap {
						bottom: 0;
					}
				}
			}
		}
	}
	
	.post_featured.hover_shop {
		.mask {
			display: block;
			opacity: 0;
			background-color: rgba(0, 0, 0, 0.1);
			@include transition-all(0.3s);
		}
		.top-info {
			pointer-events: none;
			@include abs-pos(23px, 23px, auto, auto, 10);
			@include wishlist_icon();
		}
		.bottom-info {
			opacity: 0;
			@include transition-all(0.2s);
			@include abs-pos(auto, 0, 0, 0, 10);
			pointer-events: none;
			background-color: var(--theme-color-alter_bg_color);
			height: 52px;			
			.woosq_wrap {
				width: 100%;
				padding: 5px;
				display: flex;
				flex-direction: column;
				align-items: center;
				justify-content: center;
				height: 100%;
				position: relative;
				bottom: -4px;
				@include transition-all(0.2s);
				.woosq-btn {
					display: flex;
					flex-direction: row;
					justify-content: center;
					align-items: center;
					height: 100%;
					width: 100%;
					pointer-events: auto;
					white-space: normal;
					@include box-shadow(none);
					@include border-radius(0);
					padding: 0;
					margin: 0;
					background: none !important;
					color: var(--theme-color-alter_dark);
					line-height: 16px;
					font-size: 14px;
					font-weight: 700;
					&:before {
						font-family: $theme_icons !important;
						content: '\e843';
						margin: 0 8px 0 0;
						font-size: 16px;
						font-weight: 400;
						position: relative;
						top: 0;
					}
					&:hover {
						color: var(--theme-color-alter_text);
					}
				}
			}
		}		
	}
}

@mixin mini_pure ($start: 1, $end: 1, $class: '') {
	$var: '';
	$sep: ',';
	@for $i from $start through $end {
		@if $end == $i {
			$sep: '';
		}
		$var: $var + "ul.products.products_style_pure.columns-#{$i} li.product" + $sep;
	}

	@if($class != '' or ($start == 0 or $end == 0)) {
		$var: "ul.products.products_style_pure#{$class} li.product";
	}

	#{$var} {
		.outofstock_label,
		.onsale {
			top: 15px;
			left: 15px;
			padding: 0 10px;
			min-width: 30px;
		}
		.outofstock_label {
			top: 15px;
			left: 15px;
			+ .onsale {
				top: 46px;
				left: 15px;
				right: auto;
			}
		}
		.top-info {
			top: 15px;
			right: 15px;
		}
		.bottom-info {
			height: 40px;
		}
	}
}

@media #{$media_lg_over} {
	body.body_style_ {
		&fullwide,
		&fullscreen {
			@include mini_pure(6,8);
		}
		&wide,
		&boxed {
			@include mini_pure(5,8);
		}
	}
}
@media #{$media_lg} {
	body[class*="body_style_"] {
		@include mini_pure(0,0, ':not(.columns-1):not(.columns-2)');
	}
}
@media #{$media_sm} {
	body[class*="body_style_"] {
		@include mini_pure(0,0);
	}
}



/* Widget "WooCommerce Search"
------------------------------------------------------ */
.trx_addons_woocommerce_tools {
	border-bottom: 1px solid var(--theme-color-bd_color);
}

/* Type: Filter */
.trx_addons_woocommerce_search_type_filter {
	font-size: 17px;
	.sc_form_field {
		.sc_form_field_title_caption {
			@include font(19px, 22px, 700);
			color: var(--theme-color-text_dark);
			@include transition-all(0.3s);
		}
		.sc_form_field_title:hover .sc_form_field_title_caption {
			color: var(--theme-color-text);
		}
		.sc_form_field_title.sc_form_field_title_filled .sc_form_field_title_caption {
			font-weight: inherit;
			color: var(--theme-color-text_link2);
			font-weight: 700;
		}
		.sc_form_field_arrow:before {
			content: '\e9ea';
			font-family: $theme_icons;
		}
		&.sc_form_field_opened .sc_form_field_arrow:before {
			content: '\e9d4';
			@include transform(none);
		}
		.sc_form_field_selected_items {
			color: var(--theme-color-text);
			@include font(15px, 18px);
		}		
		.sc_form_field_wrap .sc_form_field_items_selected {
			margin-top: 20px;
			padding-top: 15px;
			@include font(15px, 18px);
			color: var(--theme-color-text);
			border-top: 1px solid var(--theme-color-bd_color);
			.sc_form_field_items_selected_clear, 
			.sc_form_field_items_selected_select_all {
				text-decoration: none;
				color: var(--theme-color-text);
				&:hover {
					color: var(--theme-color-text_dark);
				}
			}
		}

		.sc_form_field_wrap .sc_form_field_item {
			padding: 0;
			.sc_form_field_item_total {
				margin: -0.5em -0.5em 0 0.5em;
				margin-top: -0.5em;
				font-size: 0.75em;
				color: inherit;
			}
			&:hover,
			&:focus {
				background-color: transparent;
			}
		}

		.sc_form_field_wrap .sc_form_field_buttons .sc_button {
			padding: 0.6em 2em;
			text-transform: inherit;
		}

		// button
		&.sc_form_field_button {
			.sc_form_field_items {
				margin: -3px;
				.sc_form_field_item {
					width: auto;
					max-width: 100%;					
					padding: 0;
					margin: 3px;
					.sc_form_field_item_label {
						@include border-radius(0);
						@include box(auto, auto);
						@include transition-all(0.3s);
						@include font(16px, 18px);
						padding: 10px 20px;
						color: var(--theme-color-alter_text);
						border-color: var(--theme-color-alter_bd_color);
						background-color: var(--theme-color-alter_bg_color);
						&:hover {
							background-color: var(--theme-color-bg_color);
						}
					}
					&.sc_form_field_item_checked .sc_form_field_item_label {
						color: var(--theme-color-alter_dark);
						border-color: var(--theme-color-alter_dark);
					}
				}
			}
		}

		// color
		&.sc_form_field_color {
			.sc_form_field_items {
				margin: -3px;
				color: var(--theme-color-text);
				.sc_form_field_item {	
					margin: 3px;
					padding: 10px 5px;
					@include border-radius(0);
					@include box(auto, auto);
					min-width: calc(20% - 6px);
					max-width: 100%;
					.sc_form_field_item_image {
						@include square(26px);
						border: 1px solid rgba(0, 0, 0, 0.09);
						position: relative;
						&:after {
							@include border-box;
							@include border-round;
							@include abs-pos(-4px, -4px, -4px, -4px);
							border: 1px solid transparent;
							@include transition-all(0.3s);
							content: '';
						}
					}
					&:hover,
					&:focus {
						background-color: transparent;
						.sc_form_field_item_image:after {
							border-color: var(--theme-color-text_dark);
						}
					}
					&.sc_form_field_item_checked {
						background-color: var(--theme-color-alter_bg_color);
						color: var(--theme-color-alter_dark);
						.sc_form_field_item_image {
							border: 1px solid rgba(0, 0, 0, 0.09);
							&:before {
								@include abs-pos(0, 0, 0, 0);
								border: none;
								content: '\e8ab';
								font-size: 14px;
								font-family: $theme_icons;
								color: #fff;
							}
						}
					}
					.sc_form_field_item_label {
						@include font(14px, 16px);
						margin-top: 6px;
					}
					.sc_form_field_item_total {
						margin-right: 0;
					}
				}
			}
		}

		// select
		&.sc_form_field_select {
			.sc_form_field_wrap .sc_form_field_item {
				margin: 0;
				padding-right: 6px;
				color: var(--theme-color-text_dark);
				@include transition-color(0.3s);
				&:hover {
					color: var(--theme-color-text);
				}
				+ .sc_form_field_item {
					margin-top: 5px;
				}
				.sc_form_field_item_total {
					@include abs-rc(0);
					margin-top: 1px;
				}
				.star-rating {
					top: 2px;
				}
			}
			&:not([data-multiple="1"]) {
				.sc_form_field_wrap	.sc_form_field_item.sc_form_field_item_checked {
					font-weight: inherit;
					text-decoration: none;
					color: var(--theme-color-text_link2);
				}
			}
			&[data-multiple="1"] {
				.sc_form_field_wrap .sc_form_field_item {
					padding-left: 30px;
					&:before {
						left: 0;
						font-family: $theme_icons;
						display: block;
						font-size: 14px;
						@include box(22px, 22px, 21px);
						@include border-radius(6px);
						border: 1px solid var(--theme-color-bd_color);
						background-color: var(--theme-color-alter_bg_color);
						margin-top: -10px;
					}
					&.sc_form_field_item_checked:before {
						content: '\e8a6';
						border-color: var(--theme-color-bd_color);
						background-color: var(--theme-color-alter_bg_color);
						color: var(--theme-color-alter_dark);
					}
				}
			}
		}

		// image
		&.sc_form_field_image {
			.sc_form_field_items {
				margin: -3px;
				.sc_form_field_item {
					@include box(calc(25% - 6px), auto);
					max-width: 100%;
					margin: 3px;
					.sc_form_field_item_image {
						@include box(100%, 100%);
						max-height: 60px;
						@include border-radius(10px);
						border: 1px solid var(--theme-color-bd_color);
						background-size: cover;
						&:before {
							content: '';
							display: block;
							width: 0;
							height: 0;
							padding-top: 100%;
						}
					}
					&:hover,
					&.sc_form_field_item_checked {						
						.sc_form_field_item_image {
							border-color: var(--theme-color-text_dark);
						}
					}
					&.sc_form_field_item_checked {
						color: var(--theme-color-text_dark);
					}			
					.sc_form_field_item_label {
						@include font(14px, 16px);
						margin-top: 6px;
					}
				}
			}
		}

		// price
		&.sc_form_field_price {
			div.ui-slider .ui-slider-handle,
			div.ui-slider .ui-slider-range {
				background-color: var(--theme-color-text_dark);
			}
			div.ui-slider {
				background-color: var(--theme-color-bd_color);
			}
			div.ui-slider-horizontal {
				height: 3px;
			}
			.trx_addons_range_slider_label {
				font-size: 15px;
				line-height: 1em;
				font-weight: inherit;
			}
			.trx_addons_range_slider_label_cur {
				font-size: 14px;
				background: none;
				color: var(--theme-color-text_dark);
				+ .trx_addons_range_slider_label_cur {
					margin-left: -4px;
				}
			}
			div.ui-slider .ui-slider-handle {
				width: 6px;
				height: 9px;
				line-height: 9px;
				border: none;
			}
			div.ui-slider-horizontal .ui-slider-handle {
				top: -3px;
				margin-left: -3px;
			}
			.sc_form_field_wrap .trx_addons_range_result {
				margin-top: 0;
				padding-top: 10px;
				font-size: 16px;
				line-height: 1em;
				color: var(--theme-color-text);
			}
			.trx_addons_range_slider_label_min {
				left: -3px;
			}
			.trx_addons_range_slider_label_max {
				right: -3px;
			}
			&.sc_form_field_slider,
			&.sc_form_field_range {
				.sc_form_field_wrap {
					margin: 0;
					.trx_addons_range_slider {
						display: block;
						margin: 0.5em 4px 1.5em;
					}
					.trx_addons_range_result {
						margin-top: 8px;
						font-size: 16px;
						line-height: 1em;
						color: var(--theme-color-text);
						.trx_addons_range_result_value {
							color: var(--theme-color-text_dark);
						}
					}
				}
			}
		}

		// text
		&.sc_form_field_text .sc_form_field_wrap {
			.sc_form_field_input {
				padding: 0 0 10px 0;
				border: none;
				background-color: transparent;
				border-bottom: 1px solid var(--theme-color-input_bd_color);
			}
			.sc_form_field_buttons {
				margin-top: 1em;
			}
		}

		// rating
		&.sc_form_field_select {
			 .sc_form_field_wrap .sc_form_field_item .star-rating span:before {
				color: var(--theme-color-text_dark);
			  }
		}
	}
	
	.trx_addons_woocommerce_search_form_fields_wrap {
		.trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all {
			color: var(--theme-color-text);
			&:hover {
				color: var(--theme-color-text_dark);
			}
			&:before {
				display: none;
			}
			&:after {
				content: '\e9e1';
				font-family: $theme_icons;
				margin-left: 10px;
				font-size: 8px;
				position: relative;
				top: 1px;
			}
		}
		&.trx_addons_woocommerce_search_form_fields_filled .trx_addons_woocommerce_search_header .trx_addons_woocommerce_search_clear_all {
			display: flex;
			align-items: center;
			flex-direction: row;
		}
		.trx_addons_woocommerce_search_button_show .trx_addons_woocommerce_search_button_show_total {
			margin: -3px 0 0 0.5em;
			font-size: 11px;
			font-weight: 400;
			@include box(22px, 22px, 20px);
			color: var(--theme-color-inverse_link);
			background-color: var(--theme-color-inverse_dark);
		}
	}

	.sidebar & {
		margin-top: -20px;
		.trx_addons_woocommerce_search_header {
			.trx_addons_woocommerce_search_clear_all {
				padding: 20px 0;
				margin-bottom: 10px;
				font-size: 16px;
				line-height: 20px;
				border-color: var(--theme-color-bd_color);
			}
		}
		.sc_form_field {
			border: none;
			.sc_form_field_wrap {
				padding-bottom: 30px;
			}
			.sc_form_field_title {
				padding: 20px 0;
				.sc_form_field_title_caption {
					color: var(--theme-color-text_dark);
				}								
				&:hover .sc_form_field_title_caption {
					color: var(--theme-color-text);
				}
				&.sc_form_field_title_filled .sc_form_field_title_caption {
					color: var(--theme-color-text_link2);
				}
				.sc_form_field_arrow {
					@include abs-rt(0, 21px);
					margin-left: 0;
				}
			}
		}
		
		.trx_addons_woocommerce_search_form_fields_wrap .trx_addons_woocommerce_search_button_show {
			@include border-radius(0);
			z-index: 9;
			margin-top: 1em;
		}
		@media #{$media_md} {
			&.trx_addons_woocommerce_search_apply .trx_addons_woocommerce_search_button_show {
				bottom: -30px;
			}
		}
	}

	// woocommerce_tools
	.trx_addons_woocommerce_tools & {
		.sc_form_field {
			.sc_form_field_wrap {
				border-color: var(--theme-color-alter_bd_color);
				background-color: var(--theme-color-alter_bg_color);
				.sc_form_field_buttons .sc_button {
					@include box-shadow(none);
				}
			}
			.sc_form_field_arrow {
				font-size: 13px;
				top: -2px;
				position: relative;
			}
			.sc_form_field_title:hover .sc_form_field_title_caption {
				text-decoration: none;
			}
		}		
	}

	.trx_addons_woocommerce_tools &,
	[class*="scheme_"].sidebar & {
		.sc_form_field {
			.sc_form_field_selected_items {
				color: var(--theme-color-alter_text);
			}		
			.sc_form_field_title_caption {
				color: var(--theme-color-alter_dark);
			}
			.sc_form_field_title:hover .sc_form_field_title_caption {
				color: var(--theme-color-alter_text);
			}
			.sc_form_field_wrap .sc_form_field_items_selected {
				border-color: var(--theme-color-alter_bd_color);
				color: var(--theme-color-alter_text);
				.sc_form_field_items_selected_clear, 
				.sc_form_field_items_selected_select_all {
					color: var(--theme-color-alter_text);
					&:hover {
						color: var(--theme-color-alter_dark);
					}
				}
			}

			&.sc_form_field_button .sc_form_field_items .sc_form_field_item {
				.sc_form_field_item_label {
					color: var(--theme-color-text);
					border-color: var(--theme-color-bd_color);
					background-color: var(--theme-color-bg_color);
					&:hover {
						background-color: var(--theme-color-alter_bg_color);
					}
				}
				&.sc_form_field_item_checked .sc_form_field_item_label {
					color: var(--theme-color-text_dark);
					border-color: var(--theme-color-text_dark);
				}
			}

			&.sc_form_field_color {
				.sc_form_field_items {
					color: var(--theme-color-alter_text);
					.sc_form_field_item {
						&:hover,
						&:focus {
							.sc_form_field_item_image:after {
								border-color: var(--theme-color-alter_dark);
							}
						}
						&.sc_form_field_item_checked {
							background-color: var(--theme-color-bg_color);
							color: var(--theme-color-alter_dark);
						}						
					}
				}
			}

			&.sc_form_field_select {
				.sc_form_field_wrap .sc_form_field_item {
					color: var(--theme-color-alter_dark);
					&:hover {
						color: var(--theme-color-alter_text);
					}
				}				
				&:not([data-multiple="1"]) {
					.sc_form_field_wrap .sc_form_field_item.sc_form_field_item_checked {
						color: var(--theme-color-alter_link2);
					}
				}
				&[data-multiple="1"] {
					.sc_form_field_wrap .sc_form_field_item {
						&:before {
							border-color: var(--theme-color-alter_bd_color);
							background-color: var(--theme-color-bg_color);
						}
						&.sc_form_field_item_checked:before {
							border-color: var(--theme-color-alter_bd_color);
							background-color: var(--theme-color-bg_color);
							color: var(--theme-color-text_dark);
						}
					}
				}				
			}

			&.sc_form_field_image .sc_form_field_items .sc_form_field_item {
				.sc_form_field_item_image {
					border-color: var(--theme-color-alter_bd_color);
				}
				&:hover,
				&.sc_form_field_item_checked {
					.sc_form_field_item_image {
						border-color: var(--theme-color-alter_dark);
					}
				}
				&.sc_form_field_item_checked {
					color: var(--theme-color-alter_dark);
				}
			}

			&.sc_form_field_price {
				div.ui-slider .ui-slider-handle,
				div.ui-slider .ui-slider-range {
					background-color: var(--theme-color-alter_dark);
				}
				div.ui-slider {
					background-color: var(--theme-color-alter_bd_color);
				}
				.trx_addons_range_slider_label_cur {
					color: var(--theme-color-alter_dark);
				}
				.sc_form_field_wrap .trx_addons_range_result {
					color: var(--theme-color-alter_text);
				}
				&.sc_form_field_slider,
				&.sc_form_field_range {
					.sc_form_field_wrap .trx_addons_range_result {
						color: var(--theme-color-alter_text);
						.trx_addons_range_result_value {
							color: var(--theme-color-alter_dark);
						}
					}					
				}
			}
		}
		.trx_addons_woocommerce_search_header {
			.trx_addons_woocommerce_search_clear_all {
				border-color: var(--theme-color-alter_bd_color);
			}
		}
	}
}


/* Type: Form */
.trx_addons_woocommerce_search_type_form {
	.sc_form_field input[type="text"] {
		padding-left: 0;
		padding-right: 0;
	}
}


/* Type: Inline */
.trx_addons_woocommerce_search_type_inline {
	@include font(1.3rem, 1.6em);
	.trx_addons_woocommerce_search_form_field_list {
		color: var(--theme-color-alter_text);
		border-color: var(--theme-color-alter_bd_color);
		background-color: var(--theme-color-alter_bg_color);
		top: 3em;
		li + li {
			margin-top: 0;
		}
		li:hover {
			color: var(--theme-color-alter_dark);
			background-color: var(--theme-color-alter_bg_hover);
		}
	}
	.trx_addons_woocommerce_search_form_field input[type="text"] {
		font-size: inherit;
		width: 5em;
	}
	.trx_addons_woocommerce_search_form_options {
		width: 75%;
	}
	.trx_addons_woocommerce_search_form_button {
		width: 25%;
		.trx_addons_woocommerce_search_button {
			padding: 16px 30px;
			white-space: normal;
			&:before {
				font-family: $theme_icons;
				content: '\e9a6';
				font-weight: 400;
			}
		}
	}	
	.trx_addons_woocommerce_search_form_field {
		input[type="text"],
		.trx_addons_woocommerce_search_form_field_label {
			line-height: 1;
			border-color: var(--theme-color-text_link);
			color: var(--theme-color-text_link);
			&:hover,
			&:focus {
				border-color: var(--theme-color-text_hover);
				color: var(--theme-color-text_hover);
			}
		}
	}

	.sidebar & {
		@include font(1.1rem, 1.7em);
		.trx_addons_woocommerce_search_form_options {
			width: 100%;
		}
		.trx_addons_woocommerce_search_form_button {
			width: 100%;
			margin-top: 1.3em;
			text-align: center;
		}
	}
}


/* BG search loading for woo filter */
.trx_addons_woocommerce_search_loading .trx_addons_loading {
	background-color: var(--theme-color-bg_color_07);
	min-height: 35px;
}


/* WooCommerce Additional attributes for Variations */
.trx_addons_attrib_button + .trx_addons_attrib_extended {
	margin-bottom: -4px;
}
.trx_addons_attrib_image + .trx_addons_attrib_extended {
	margin-bottom: -4px;
}
.trx_addons_attrib_color + .trx_addons_attrib_extended {
	margin-bottom: -9px;
}
div.product form.cart .variations .value > .select_container {
	margin-top: -0.7em;
}

.trx_addons_attrib_item {
	&[data-tooltip-text] {
		&:before,
		&:after {
			display: none;
		}
	}
	&.trx_addons_attrib_disabled span:before,
	&.trx_addons_attrib_disabled span:after {
		background-color: var(--theme-color-alter_hover);
	}

	&.trx_addons_attrib_color {
		margin: 0 9px 9px 0;
		padding: 0;
		background: none;		
		border: none;
		position: relative;
		overflow: visible;
		@include border-box();
		@include border-radius(50%);
		&:after {
			content: '';
			display: block;
			padding: 0;
			position: absolute;
			top: -3px;
			left: -3px;
			z-index: 1;
			opacity: 1;
			background: none;
			@include transform(none);
			@include border-radius(50%);
			@include transition-all(0.2s);
			@include border-box();
			border: 1px solid transparent;
			@include box(calc(100% + 6px), calc(100% + 6px), 1);
			pointer-events: auto;		
		}
		span {
			@include box(15px, 15px, 15px);
			border: 1px solid rgba(0,0,0,0.09);
			@include transition-all(0.2s);
			@include border-radius(50%);
			@include border-box();
		}
		&.trx_addons_attrib_selected,
		&:hover {
			span {
				border-color: transparent;
			}
			&:after {
				border-color: var(--theme-color-text_dark);
			}
		}
	}
	
	&.trx_addons_attrib_button {
		margin: 0 4px 4px 0;
		padding: 4px 7px;
		min-width: 26px;
		text-align: center;
		@include border-box();
		@include border-radius(0);
		@include font(14px, 17px);
		@include transition-all(0.2s);
		border: 1px solid var(--theme-color-alter_bd_color);
		background-color: var(--theme-color-alter_bg_color);
		color: var(--theme-color-alter_text);
		span {
			padding: 0;
		}
		&.trx_addons_attrib_selected,
		&:hover {
			color: var(--theme-color-alter_text);
			border-color: var(--theme-color-alter_dark);
		}
	}

	&.trx_addons_attrib_image {
		margin: 0 4px 4px 0;
		padding: 0;
		@include box(57px, 57px, 1);
		@include border-radius(5px);
		@include transition-all(0.2s);
		position: relative;
		z-index: 1;
		overflow: hidden;
		border: 1px solid var(--theme-color-alter_bd_color);
		background-color: var(--theme-color-alter_bg_color);
		cursor: pointer;
		&.trx_addons_attrib_selected,
		&:hover {
			border-color: var(--theme-color-alter_dark);
		}
		img {
			@include border-radius(0);
			border: none;
			@include scale(1, 1);
		}
	}
}